("\"encryption\" features from the preference panel" "\"ĉifrado\" funkcioj de la preferopanelo")
("(Re)Build autocompletion index" "(Re) Konstruu aŭtokompletigan indicon")
("a modifier" "modifilo")
("a series" "serio")
("a.C.M. computing class" "a.C.M. komputada klaso")
("a.M.S. subject class" "a.M.S. subjektoklaso")
("abbreviated authors" "mallongigitaj aŭtoroj")
("abbreviation" "mallongigo")
("about" "pri")
("about menu" "pri menuo")
("above" "supre")
("abreviated authors" "mallongigitaj aŭtoroj")
("abstract" "abstrakta")
("accent" "akcento")
("accent above" "akcento supre")
("accent below" "akcento sube")
("accept" "akcepti")
("accept all scripts" "akceptu ĉiujn skriptojn")
("accept during this pass" "akceptu dum ĉi tiu enirpermesilo")
("accept no scripts" "akceptu neniujn skriptojn")
("accept script" "akcepti skripton")
("acknowledgment" "agnosko")
("acknowledgments" "agnoskoj")
("acronym" "akronimo")
("action" "ago")
("activate" "aktivigi")
("activate hidden" "aktivi kaŝita")
("activate once" "aktivi unufoje")
("activation" "aktivigo")
("active link types" "aktivaj ligotipoj")
("acute" "akra")
("add" "aldoni")
("add abstract information" "Aldoni abstraktajn informojn")
("add author information" "Aldonu informojn pri aŭtoro")
("add branch after" "Aldoni branĉon post")
("add branch before" "Aldonu branĉon antaŭe")
("add other package" "Aldonu alian pakaĵon")
("add package" "aldoni pakaĵon")
("add style package" "Aldoni stilpakaĵon")
("add switch after" "aldoni ŝaltilon post")
("add switch before" "aldonu ŝaltilon antaŭe")
("add title information" "Aldoni informojn pri titolo")
("addition" "aldono")
("address" "adreso")
("address block" "adreso-bloko")
("adjust" "ĝustigi")
("adjust limits" "ĝustigi limojn")
("advanced" "progresinta")
("advanced font customization" "Altnivela tiparo")
("advanced layout features" "altnivelaj aranĝoj")
("affiliation" "aliĝo")
("after" "post")
("albanian" "albanian")
("algorithm" "algoritmo")
("align cell to the bottom" "vicigi ĉelon al la fundo")
("align cell to the decimal comma" "aligi ĉelon al la dekuma komo")
("align cell to the decimal dot" "vicigi ĉelon al la dekuma punkto")
("align cell to the left" "vicigi ĉelon maldekstren")
("align cell to the right" "vicigi ĉelon dekstren")
("align cell to the top" "vicigi ĉelon al la supro")
("align table at axis" "vicigi tablon ĉe akso")
("align table at base of left column" "vicigi tablon ĉe la bazo de maldekstra kolumno")
("align table at base of middle column" "vicigi tablon ĉe bazo de meza kolumno")
("align table at base of origin column" "vicigi tablon ĉe la origina kolumno")
("align table at base of right column" "vicigi tablon ĉe la bazo de dekstra kolumno")
("align table at fraction bar height" "vicigi tablon ĉe frakcia stanta alteco")
("align table at the base of bottom row" "vicigi tablon en la fundo de malsupra vico")
("align table at the base of middle row" "vicigi tablon ĉe la bazo de meza vico")
("align table at the base of origin row" "vicigi tablon ĉe la bazo de origina vico")
("align table at the base of top row" "vicigi tablon ĉe la bazo de la supra vico")
("align table at the bottom" "vicigi tablon ĉe la fundo")
("align table at the center" "vicigi tablon en la centro")
("align table at the horizontal center" "vicigi tablon ĉe la horizontala centro")
("align table at the left" "vicigi tablon maldekstre")
("align table at the top" "vicigi tablon ĉe la supro")
("align table to the right" "vicigi tablon dekstren")
("align text to the left" "vicigi tekston maldekstren")
("align text to the right" "vicigi tekston dekstren")
("aligned" "vicigitaj")
("alignment" "aligxo")
("alignment of balloon" "vicigo de balono")
("all" "ĉiuj")
("all cells" "ĉiuj ĉeloj")
("all data attached to this identity will be lost" "ĉiuj datumoj ligitaj al ĉi tiu identeco estos perditaj")
("all saved passphrases will be lost forever" "ĉiuj konservitaj pasfrazoj estos perditaj por ĉiam")
("allow" "permesi")
("allow for macro definitions in preamble" "Permesu makro-difinojn en enkonduko")
("allowed extension" "permesita etendo")
("allowed page height extension" "permesita pligrandigo de paĝo")
("allowed page height reduction" "permesita redukto de alteco de paĝo")
("allowed positions" "permesitaj pozicioj")
("allowed positions of floating object" "permesitaj pozicioj de flosanta objekto")
("allowed reduction" "Permesita redukto")
("alpha release" "alfa-liberigo")
("alpha transparency" "alfa travidebleco")
("also on paper" "ankaŭ sur papero")
("alt key" "altŝlosilo")
("alter" "alter")
("alternate" "alterno")
("alternate except here" "alternas krom ĉi tie")
("alternate from here on" "alternu de ĉi tie")
("alternate only here" "alternu nur ĉi tie")
("alternate until here" "alterne ĝis ĉi tie")
("alternative specification" "alternativa specifo")
("always" "ĉiam")
("american" "usonano")
("amplified" "amplifita")
("and" "kaj")
("and perform casual settings from the \"Encryption\" tab" "kaj plenumu hazardajn agordojn el la langeto \"Ĉifrado\"")
("angular" "angula")
("animate" "animu")
("animate folding" "vigla faldado")
("animate unfolding" "animu disfaldas")
("animated" "viglaj")
("animation" "kuraĝigo")
("animation toolbar" "Animacia ilobreto")
("annotate" "komenti")
("answer" "respondo")
("answer field" "responda kampo")
("answer to question" "respondo al demando")
("answers only" "nur respondoj")
("any" "ajn")
("appear" "aperi")
("appendix" "apendico")
("apply" "apliki")
("apply macro" "apliki makroon")
("apply macro once" "apliki makroon unufoje")
("approximate" "proksimuma")
("april" "Aprilo")
("arab" "araba")
("arc" "arko")
("arc cosine" "arko coseno")
("arc sine" "arko sine")
("arc tangent" "arka tanĝento")
("arch series" "arka serio")
("archaic" "arkaika")
("architecture" "arkitekturo")
("are you sure you want to delete collected public keys" "Ĉu vi certas, ke vi volas forigi kolektitajn publikajn ŝlosilojn")
("are you sure you want to delete selected public keys" "Ĉu vi certas, ke vi volas forigi elektitajn publikajn ŝlosilojn")
("are you sure you want to delete selected secret keys" "Ĉu vi certas, ke vi volas forigi elektitajn sekretajn ŝlosilojn")
("are you sure you want to destroy the wallet" "Ĉu vi certas, ke vi volas detrui la monujo")
("argument" "argumento")
("arithmetic" "aritmetiko")
("armenian" "informu")
("arrow" "sago")
("arrows" "sagoj")
("art frame" "arta kadro")
("article" "artikolo")
("arxiv category" "arxiv-kategorio")
("as on paper" "kiel sur papero")
("as visual grid" "kiel vida krado")
("aspect" "aspekto")
("assign" "asigni")
("at fraction bar height" "ĉe frakcia stanta alteco")
("at the baseline" "ĉe la bazlinio")
("at the bottom" "ĉe la fundo")
("at the left" "maldekstre")
("at the middle" "meze")
("at the right" "dekstre")
("at the top" "ĉe la supro")
("attach" "alligi")
("attach buffer to which project" "ligi bufron al kiu projekto")
("attach master" "ligi mastron")
("august" "aŭgusto")
("author" "aŭtoro")
("authorize" "rajtigi")
("auto" "aŭtomata")
("auto-save file" "aŭtomata konservo de dosiero")
("automatic" "aŭtomata")
("automatic brackets" "aŭtomata krampoj")
("automatic content generation" "aŭtomata enhavo-generacio")
("automatic program brackets" "aŭtomata programo krampoj")
("automatic quotes" "aŭtomataj citaĵoj")
("automatically close brackets" "aŭtomate fermu krampojn")
("automatically generated content" "aŭtomate generita enhavo")
("automatically import bibliographies when opening files" "Aŭtomate importi bibliografiojn malferminte dosierojn")
("automatically remember all passphrases in the wallet" "Aŭtomate memoru ĉiujn pasfrazojn en la monujo")
("automatically save" "aŭtomate konservi")
("autosave" "Aŭtvojo")
("axiom" "aksiomo")
("axis" "akso")
("b series" "b serio")
("back" "reen")
("background" "fono")
("background color" "fonkoloro")
("background evaluations" "fonaj taksadoj")
("backtrace errors" "retrorigardaj eraroj")
("backward replace" "malantaŭen anstataŭi")
("backward search" "malantaŭa serĉo")
("bad data format" "Malbona datumformato")
("bar" "trinkejo")
("bard" "bardo")
("base" "bazo")
("base level" "baznivelo")
("baseline" "bazlinio")
("bashkirian" "bashkirian")
("basic" "baza")
("basic communication using pipes" "baza komunikado uzante pipojn")
("basic data types" "bazaj datumtipoj")
("basic types" "bazaj tipoj")
("be useful" "esti utila")
("beamer" "beamer")
("beamer formats" "beamer-formatoj")
("beamer theme" "beamer-temo")
("become a TeXmacs developer" "fariĝu programisto de TeXmacs")
("before" "antaŭ")
("begin" "komenci")
("below" "sube")
("bench" "benko")
("bend bottom" "fleksiĝu fundo")
("bend corner" "kurbiĝema angulo")
("bend diagonal" "kurbiĝema diagonalo")
("bend in" "klinu")
("bend out" "kliniĝu")
("beta release" "beta-liberigo")
("bezier" "bezier")
("bibTeX command" "bibTeX-komando")
("bibliography" "bibliografio")
("bibliography file" "bibliografia dosiero")
("bibliography style" "bibliografia stilo")
("bidirectional" "bidirekcia")
("big" "granda")
("big environment box" "granda medio-skatolo")
("big figure" "granda figuro")
("big focus" "granda fokuso")
("big operator" "granda telefonisto")
("big skip" "granda skipo")
("big table" "granda tablo")
("binary operation" "binara operacio")
("binary operator" "binara telefonisto")
("binary relation" "binara rilato")
("bitmap resolution (dpi)" "Bitmap-rezolucio (dpi)")
("black" "nigra")
("black floral I" "nigra flora I")
("black floral II" "nigra flora II")
("blackboard bold" "aŭdapaŝa litero")
("blackboard embold" "nigra tabulo")
("blackboard math" "nigra tabuleto")
("blackletter" "rubriko")
("blank column" "malplena kolumno")
("blank row" "malplena vico")
("block" "bloko")
("block content" "blokita enhavo")
("block of code" "bloko de kodo")
("blue" "blua")
("blur" "neklara")
("body" "korpo")
("bold" "aŭdaca")
("book" "libro")
("border" "limo")
("both" "ambaŭ")
("both versions" "ambaŭ versioj")
("bottom" "fundo")
("bottom baseline" "funda bazlinio")
("bottom border" "malsupra bordo")
("bottom cell border" "malsupra ĉela limo")
("bottom cell padding" "funda ĉelo")
("bottom margin" "funda marĝeno")
("bottom padding" "funda kompletigo")
("bottom table border" "malsupra tablo-limo")
("bottom table padding" "Plena tabela kompletigo")
("bottom tools" "malsupraj iloj")
("box" "skatolo")
("branch" "filio")
("break" "paŭzo")
("breaking" "rompi")
("breve" "breve")
("british" "britoj")
("broken white" "rompita blankulo")
("brown" "bruna")
("browse" "trarigardi")
("browse back" "trarigardi")
("browse forward" "trarigardi antaŭen")
("browse modules documentation" "Dokumentoj pri foliumiloj")
("browse web" "foliumas retejon")
("browser" "retumilo")
("buffer" "bufroj")
("buffer management" "bufra administrado")
("buffer must be on disk" "bufro devas esti sur disko")
("buffer must have a name" "bufro devas havi nomon")
("build buffer" "konstrua bufro")
("build buffer in" "Enkonstruu bufron en")
("build directory" "konstrua dosierujo")
("build directory in" "Konstrui dosierujon en")
("build link pages" "konstrui ligopaĝojn")
("build-all" "konstruaj-ĉiuj")
("bulgarian" "bulgara")
("bullet" "kuglo")
("bullets" "kugloj")
("bump" "frapo")
("busy" "okupata")
("by" "de")
("by typing" "tajpante")
("bytes free" "bajtoj senpagaj")
("bytes used" "uzataj bajtoj")
("cJK" "cJK")
("cJK spacing" "cJK-interspacigo")
("calculus" "kalkulo")
("calligraphic" "kaligrafa")
("cancel" "nuligi")
("cancelled" "nuligita")
("cannot download directory to file" "Ne povas elŝuti dosierujon al dosiero")
("cannot rename across different servers" "ne povas renomiĝi al diversaj serviloj")
("cannot upload directory to file" "Ne povas alŝuti dosierujon al dosiero")
("caps-lock key" "ŝlosilo-ĉeno-ŝlosilo")
("cartesian" "kartezia")
("carved wood" "skulptita ligno")
("case" "kazo")
("case-insensitive search" "serĉado de neuzaj kazoj")
("categories" "kategorioj")
("category" "kategorio")
("cc" "cc")
("cell" "ĉelo")
("cell background color" "Ĉela fonkoloro")
("cell border" "ĉela limo")
("cell height" "ĉela alteco")
("cell operation mode" "reĝimo pri ĉela operacio")
("cell properties" "Ĉelaj proprietoj")
("cell width" "ĉela larĝo")
("cells" "ĉeloj")
("center" "centro")
("center text" "centra teksto")
("centered" "centritaj")
("centered block" "centrita bloko")
("centered tabular" "Centrita tabelaro")
("change border of cell" "Ŝanĝi limon de ĉelo")
("change cell operation mode" "Ŝanĝi reĝimon de ĉela operacio")
("change default unit" "Ŝanĝi defaŭlta unuo")
("change log" "Ŝanĝi ŝtipo")
("change passphrase" "ŝanĝi pasfrazon")
("change step-size" "ŝanĝi paŝograndecon")
("change tags" "ŝanĝi etikedojn")
("change the TeXmacs preferences" "ŝanĝi la preferojn de TeXmacs")
("change the border of the table" "Ŝanĝu la limon de la tablo")
("change the style of mathematical formulas" "ŝanĝu la stilon de matematikaj formuloj")
("changes" "ŝanĝoj")
("chapter" "ĉapitro")
("character contraction" "Karaktero kuntiriĝo")
("character encoding" "karaktera kodado")
("character expansion" "karaktero-vastiĝo")
("check" "ĉeko")
("check for updates" "Kontrolu ĝisdatigojn")
("check text for spelling errors" "kontrolu tekston por ortografiaj eraroj")
("checkable field" "kontrolebla kampo")
("chinese" "ĉina")
("choice" "elekto")
("cipher algorithm for passphrase encryption" "ĉifrita algoritmo por pasfrasa ĉifrado")
("circle" "cirklo")
("citation" "citaĵo")
("cite" "citi")
("class" "klaso")
("classification" "klasifiko")
("clean slate" "pura ardezo")
("clear" "klara")
("clear all fields" "Forigi ĉiujn kampojn")
("clear local information" "klaraj lokaj informoj")
("clear menu" "klara menuo")
("clear selection" "klara elekto")
("clear undo history" "klara malfaru historion")
("click Ok button twice to discard this warning" "alklaku Ok butonon dufoje por forĵeti ĉi tiun averton")
("clip" "tranĉeto")
("clipboard image format" "klipo bildo formato")
("clipped" "alkroĉita")
("clipped and magnified" "alkroĉitaj kaj grandigitaj")
("clipped and resized" "alkroĉita kaj grandigita")
("clone" "klono")
("clone window" "klona fenestro")
("close" "proksima")
("close TeXmacs" "fermi TeXmacs")
("close animation tool" "proksima kuraĝiga ilo")
("close buffer" "proksima bufro")
("close document" "proksima dokumento")
("close program" "proksima programo")
("close replace tool" "Fermi anstataŭan ilon")
("close search tool" "proksima serĉilo")
("close session" "proksima kunsido")
("close spell tool" "proksima sorĉa ilo")
("close translations to rebuild" "proksimaj tradukoj rekonstrui")
("close window" "fermi fenestron")
("closed bezier" "fermita bezier")
("closed curve" "fermita kurbo")
("closed smooth" "fermita glata")
("closed spline" "fermita splino")
("closing" "fermo")
("closing style" "ferma stilo")
("cluster by affiliation" "aglomeraĵo per apartigo")
("code" "kodo")
("collect garbage" "kolekti rubon")
("collected keys" "kolektitaj ŝlosiloj")
("color" "koloro")
("color of the axes" "koloro de la aksoj")
("color of the subunits" "koloro de la subunuoj")
("color of the units" "koloro de la ekzempleroj")
("colors" "koloroj")
("column" "kolumno")
("column contains glued items" "kolumno enhavas gluitajn erojn")
("column to the left" "kolumno maldekstre")
("column to the right" "kolumno dekstre")
("columns" "kolumnoj")
("column separation" "kolumnaj disigoj")
("commit file" "kompromisi dosieron")
("common" "komuna")
("common formats" "komunaj formatoj")
("commutative diagram" "komuta diagramo")
("compact" "kompakta")
("compactification" "kompaktigado")
("compactify" "kompaktigi")
("compatibility with other formats" "kongruo kun aliaj formatoj")
("compile article" "kompilu artikolon")
("compile book" "kompillibro")
("compile buffer" "Kompila bufro")
("compile project" "kompilprojekto")
("complete bibliographic reference" "kompleta bibliografia referenco")
("completion" "kompletigo")
("complex" "kompleksa")
("complex actions" "kompleksaj agoj")
("compose" "kunmeti")
("compound" "komponaĵo")
("compress" "kunpremi")
("compress into toolbar" "kunpremi en ilobreto")
("compressed" "kunpremita")
("conceal" "kaŝi")
("concrete" "konkretaj")
("condensed" "kondensita")
("condition" "kondiĉo")
("configuration" "agordo")
("configure look and feel" "agordi aspekton kaj senton")
("confirm database entry" "Konfirmu datumbazon")
("confirm entry" "konfirmi eniron")
("confirm selected database entries" "konfirmu elektitajn datumbazojn")
("confirm selected entries" "Konfirmi elektitajn enskribojn")
("conservative conversion options" "konservativaj konvertaj elektoj")
("consoles" "konzoloj")
("constellation" "konstelacio")
("contact" "kontakto")
("content" "enhavo")
("content tag" "enhavtabelo")
("context aids" "kuntekstaj helpoj")
("context dependent icons" "kontekstaj dependaj ikonoj")
("contextual hints" "kontekstaj aludoj")
("continuation of" "daŭrigo de")
("continue" "daŭrigi")
("continued fraction" "daŭra frakcio")
("contour" "konturo")
("contract logarithms" "kontraktaj logaritmoj")
("contribute" "kontribui")
("control flow" "kontrolfluo")
("control the evaluation of expressions" "Kontrolu la taksadon de esprimoj")
("convention" "konvencio")
("convert" "konverti")
("converters" "konvertiloj")
("converters to other data formats" "konvertiloj al aliaj datumformatoj")
("convertible" "konvertebla")
("copy" "kopio")
("copy text" "kopia teksto")
("copy to" "kopii al")
("copying" "kopiado")
("copyright" "kopirajto")
("cork charset with TeX catcode definition in preamble" "korktirilo kun TeX-difino de antaŭkodo")
("corollary" "korolario")
("correct" "ĝentila")
("correct all" "korektu ĉiujn")
("correct formula" "ĝusta formulo")
("correct manually" "korektu permane")
("correct mathematical formulas" "ĝustaj matematikaj formuloj")
("correct text" "ĝusta teksto")
("correction" "korekto")
("cosine" "kosinuso")
("count characters" "nombraj signoj")
("count lines" "kalkulaj linioj")
("count words" "nombraj vortoj")
("create a new document" "krei novan dokumenton")
("create link" "krei ligon")
("create preamble" "Krei prefikson")
("create remote directory" "krei forajn dosierujon")
("create remote file" "krei forajn dosieron")
("create subprogram" "krei subprogramon")
("create subsession" "Krei subsekcion")
("create table macro" "Krei tabelon macro")
("create web site" "krei retejon")
("creating new account" "krei novan konton")
("creating technical pictures" "Krei teknikajn bildojn")
("crop" "rikolto")
("crop marks" "rikoltaj markoj")
("cross" "kruco")
("crossed boxes" "krucaj skatoloj")
("crossed circles" "krucaj rondoj")
("current user version" "aktuala uzantversio")
("current version" "aktuala versio")
("cursor" "kursoro")
("cursors" "kursoroj")
("curve" "kurbo")
("curve intersections" "kurba intersekciĝoj")
("curve points" "kurbo-punktoj")
("custom tab" "kutimo langeto")
("customizations" "personecoj")
("customizing TeXmacs" "Agordado de TeXmacs")
("customizing and extending the user interface" "Agordado kaj etendado de la uzantinterfaco")
("customizing the TeXmacs styles" "Agordi la TeXmacs-stilojn")
("custum tab" "custum-langeto")
("cut" "tranĉita")
("cut text" "tranĉita teksto")
("cut to" "tranĉita al")
("cypriot" "ciprio")
("cyrillic" "cirila")
("cyrillic input method" "cirila enira metodo")
("cyrillic italic right" "cirila kursiva rajto")
("czech" "ĉe czecha")
("dancers" "dancistoj")
("danish" "danoj")
("dark grey" "malhelgrizaj")
("dash" "streko")
("dashes" "strekoj")
("data" "datumoj")
("data conversion" "datumkonverto")
("data format" "formato de datumoj")
("database entry" "datumbazo-eniro")
("database tool" "datumbazo-ilo")
("database toolbar" "datumbazila ilobreto")
("date" "dato")
("deactivate" "malaktivigi")
("deactivate once" "malaktivigi unufoje")
("deactivate table" "malaktivigi tablon")
("dead" "mortintoj")
("debug" "elpurigi")
("debugging console" "Elpuriga konzolo")
("debugging tool" "Elpuriga ilo")
("december" "decembro")
("decimal comma" "dekuma komo")
("decimal dot" "dekuma punkto")
("decomposed" "malkomponita")
("decorate atoms" "Ornami atomojn")
("decorated" "ornamita")
("decorated wood" "ornamita ligno")
("decrease size" "malpliigi grandecon")
("decrypt" "deĉifri")
("default" "apriora")
("default padding" "defaŭlta kompletigo")
("default size" "defaŭlta grandeco")
("definition" "difino")
("degrade" "degeli")
("degraded" "degenerinta")
("delete" "forigi")
("delete column" "forigi kolumnon")
("delete documentation cache" "forigi dokumentokodon")
("delete entries" "forigi enskribojn")
("delete link" "forigi ligon")
("delete row" "forigi vico")
("deleted" "forigita")
("denominator" "nomanto")
("describe" "priskribi")
("describe tag" "priskribi etikedon")
("description" "priskribo")
("destination" "destino")
("destroy" "detrui")
("detach" "taĉmento")
("detach master" "taĉmentmajstro")
("detailed" "detala")
("detailed menus" "detalaj menuoj")
("details in menus" "detaloj en menuoj")
("determinant" "determinanto")
("determine margins from text width" "determinu randojn de larĝa teksto")
("devangari" "devangari")
("developer" "ellaboranto")
("developer tool" "programilo")
("developers guide" "programistoj gvidas")
("device" "aparato")
("diamond" "diamanto")
("differentiate" "diferencigi")
("dilate" "dilate")
("direction of progression" "direkto de progresado")
("direction of translation" "direkto de traduko")
("directory" "adresaro")
("disable" "malebligi")
("disable coloring on paper" "malebligi kolorigon sur papero")
("disable encryption" "malebligi ĉifradon")
("disable first indentation" "malebligi unuan indentacion")
("disable first indentation after" "Malebligu unuan indentation post")
("disable first indentation before" "Malebligu unuan indentacion antaŭe")
("disable indentation" "malebligi indentacion")
("disable indentation after" "malebligi indentacion post")
("disable indentation before" "malebligu indentacion antaŭe")
("disallow" "malakcepti")
("disappear" "malaperas")
("disk" "disko")
("display style" "montra stilo")
("displayed formula" "montrita formulo")
("dissociate joined cells" "disigi kunigitaj ĉeloj")
("distort" "distordo")
("distorted" "distorsita")
("distribute unused space" "Distribuu neuzatan spacon")
("div" "div")
("division" "divido")
("do not remap" "ne remas")
("document" "dokumento")
("document font selector" "dokumenta tiparilo")
("document format" "dokumenta formato")
("document language" "dokumentlingvo")
("document page format" "dokumenta paĝo-formato")
("document paragraph format" "dokumenta alinea formato")
("document style" "dokumenta stilo")
("document styles" "dokumentaj stiloj")
("document updates run" "dokumentaj ĝisdatigoj funkcias")
("documentation" "dokumentado")
("documents are trees" "dokumentoj estas arboj")
("dot" "punkto")
("dots" "punktoj")
("double stroke" "duobla streko")
("down" "malsupren")
("download" "elŝuti")
("downwards" "malsupren")
("dpi" "dpi")
("dragging" "trenado")
("draw image" "desegni bildon")
("draw over" "remizo")
("draw over selection" "remizo super elekto")
("drop" "faligi")
("due to" "pro")
("duplicate" "duplikato")
("dutch" "nederlanda")
("dynamic" "dinamika")
("dynamic libraries" "dinamikaj bibliotekoj")
("eRROR" "eRROR")
("edit" "redakti")
("edit animation" "redakti kuraĝigon")
("edit groups of objects" "redakti grupojn de objektoj")
("edit macro" "redakti makroon")
("edit macros" "redakti makroojn")
("edit preamble" "redakti prefikson")
("edit source" "redakti fonton")
("edit source tree" "redakti fontarbon")
("edit style" "redakta stilo")
("edit translations file" "redakti dosierojn")
("editing tools" "redaktaj iloj")
("education" "edukado")
("effect pen" "efika plumo")
("eigenvalues" "valoroj propraj")
("eighth" "oka")
("email" "retpoŝto")
("embold" "embold")
("emboss" "Emboss")
("emphasize" "emfazi")
("emphasize text" "emfazi tekston")
("empty box" "malplena skatolo")
("enable first indentation" "ebligi unuan indentacion")
("enable first indentation after" "Ebligu unuan indentacion post")
("enable first indentation before" "ebligu unuan indentacion antaŭe")
("enable indentation" "ebligi indentigon")
("enable indentation after" "ebligi indentigon post")
("enable indentation before" "ebligu indentigon antaŭe")
("enable page breaking" "ebligi rompadon de paĝoj")
("encl" "englui")
("encoding" "kodigo")
("encrypt" "ĉifri")
("encryption" "ĉifrado")
("encryption facilities are not currently available" "ĉifradaj instalaĵoj ne aktuale disponeblas")
("encryption facilities have not been enabled for TeXmacs" "ĉifradaj instalaĵoj ne ebligis por TeXmacs")
("end" "fino")
("enforce brackets to match" "Enigi krampojn por kongrui")
("english" "angla")
("engrave" "gravuraĵo")
("enter a title" "enigu titolon")
("enter data" "enigu datumojn")
("enter graphics" "enmetu grafikojn")
("enter graphics mode" "eniri grafikan reĝimon")
("enter new passphrase for encryption" "enigu novan pasfrazon por ĉifrado")
("enter passphrase for decryption" "enigu pasfrazon por malĉifrado")
("enter passphrase for identity" "enigu pasfrazon por identeco")
("enter title information" "enigu titolajn informojn")
("entire table" "tuta tablo")
("entry up to date in database" "eniro ĝisdatigita en datumbazo")
("enumerate" "numeri")
("enumerate|Alpha" "enumere | Alfa")
("enumerate|Roman" "enume | roma")
("enumerate|alpha" "enumere | alfa")
("enumerate|roman" "enumerate | roman")
("enunciation" "enunciacio")
("env" "env")
("environment" "medio")
("environment variable" "media variablo")
("environments" "medioj")
("epilogue" "epilogo")
("equal" "egala")
("equation" "ekvacio")
("equations" "ekvacioj")
("equivalent for" "ekvivalento por")
("erode" "eroziigas")
("error" "eraro")
("error messages" "erarmesaĝoj")
("error output" "erara eligo")
("error status report" "Erara raporto")
("error: bracket does not match" "eraro: krampo ne kongruas")
("error: cyclic or missing chunks detected" "Eraro: ciklaj aŭ mankantaj pecetoj detektitaj")
("error: file not found" "eraro: dosiero ne trovita")
("error: ghostview does not seem to be installed on your system" "eraro: ghostview ne ŝajnas esti instalita en via sistemo")
("error: one of the alternatives should be filled out" "eraro: unu el la alternativoj devas esti plenigita")
("error: only one alternatives should be filled out" "eraro: nur unu alternativo estu plenigita")
("error: should fill out name for referencing" "eraro: plenigu nomon por referenci")
("error: should fill out required field" "eraro: plenigu postulatan kampon")
("esperanto" "esperanto")
("etruscan" "etrusko")
("evaluable field" "taksata kampo")
("evaluate" "taksi")
("evaluate above" "taksi supre")
("evaluate all" "taksi ĉiujn")
("evaluate below" "taksi sube")
("evaluate fields" "taksi kampojn")
("evaluate fields in order" "taksi kampojn en ordo")
("evaluate scheme expression" "taksi esprimo")
("evaluate script" "taksi skripton")
("evaluation" "takso")
("evaluation switch" "taksa ŝaltilo")
("evaluation tag" "taksata etikedo")
("even page" "eĉ paĝo")
("even page footer" "eĉ paĝo-paĝo")
("even page header" "eĉ paĝo-kaplinio")
("even page left margin" "eĉ paĝo maldekstra rando")
("even page margin" "eĉ paĝa marĝeno")
("even page shift" "eĉ paĝa ŝanĝo")
("even page text" "eĉ paĝa teksto")
("even pages" "eĉ paĝoj")
("events" "eventoj")
("exact" "ĝusta")
("exact horizontal" "ĝusta horizontalo")
("exact mode" "ĝusta reĝimo")
("exam" "ekzameno")
("example" "ekzemplo")
("exclusive" "ekskluziva")
("exclusive or" "ekskluziva aŭ")
("executable" "plenumebla")
("execute" "ekzekuti")
("execute a TeXmacs command" "ekzekutu komandon de TeXmacs")
("execute system command" "ekzekuti sistemkomandon")
("execution of scripts" "ekzekuto de skriptoj")
("executive" "plenuma")
("exercise" "ekzercado")
("exit graphics" "elirejaj grafikaĵoj")
("exit graphics mode" "eliri grafikan reĝimon")
("exit left" "eliri maldekstre")
("exit right" "eliri dekstre")
("exit tag on the left" "elira etikedo maldekstre")
("exit tag on the right" "elira etikedo dekstre")
("expand" "pligrandigi")
("expand TeXmacs macros with no LaTeX equivalents" "pligrandigu TeXmacajn makroojn kun neniu LaTeX-ekvivalentoj")
("expand beamer slides" "Pligrandigi beamer diapozitivojn")
("expand inclusions" "Pligrandigi Inkluzivojn")
("expand logarithms" "pligrandigi logaritmojn")
("expand trigonometric functions" "pligrandigi trigonometriajn funkciojn")
("expand unrecognized macros" "vastigi ne rekonitajn makroojn")
("expand user-defined macros" "vastigi uzant-difinitajn makroojn")
("expanded" "pligrandigita")
("experimental features (to be used with care)" "eksperimentaj ecoj (por uzi zorgeme)")
("explain" "klarigi")
("explained" "klarigita")
("explanatory item" "klariga ero")
("explicit keystroke" "eksplicita klavofrapo")
("explicit margins" "eksplicitaj randoj")
("exponential" "eksponenta")
("export" "eksportado")
("export as" "eksporti kiel")
("export bibliographies as links" "eksportaj bibliografioj kiel ligiloj")
("export bibliography" "eksporta bibliografio")
("export entries in buffer" "eksportaj eniroj en bufroj")
("export file" "eksportodosiero")
("export formulas as images" "eksportaj formuloj kiel bildoj")
("export mathematical formulas as MathML" "eksporti matematikajn formulojn kiel MathML")
("export mathematical formulas as images" "eksporti matematikajn formulojn kiel bildojn")
("export selected entries" "eksporti elektitajn enskribojn")
("export selection" "eksporta elekto")
("export selection as image" "eksport-elekto kiel bildo")
("export selections as" "eksportaj elektoj kiel")
("export sessions" "eksportaj kunsidoj")
("exported bibliographic entries" "eksportitaj bibliografiaj artikoloj")
("exported bibliographic references" "eksportataj bibliografiaj referencoj")
("extend" "etendi")
("extend or normal" "ampleksa aŭ normala")
("extended" "etendita")
("extensible left arrow" "etendita maldekstra sago")
("extensible right arrow" "etendebla dekstra sago")
("extern" "ekstera")
("extern " "ekstera")
("external" "ekstera")
("extra" "kroma")
("extra branch" "kroma branĉo")
("extra interline space" "kroma interlinia spaco")
("extra name" "kroma nomo")
("extract" "eltiraĵo")
("extract format" "eltira formato")
("extract style file" "Eltira stilo-dosiero")
("extract style package" "eltira stilo-pakaĵo")
("factor" "faktoro")
("fade" "fadi")
("fade in" "fadi en")
("fade out" "Fade out")
("family" "familio")
("fast" "rapida")
("fast decrease" "rapida malkresko")
("fast environments" "rapidaj medioj")
("fast increase" "rapida kresko")
("february" "februaro")
("field reference" "kampo-referenco")
("fifth" "kvina")
("figure" "cifero")
("file" "dosiero")
("file name" "dosiernomo")
("file not found" "dosiero ne trovita")
("file saved" "konservita dosiero")
("fill color" "pleniga koloro")
("fill out" "plenigu")
("filter" "filtrilo")
("find file" "trovi dosieron")
("find next match" "trovi sekvan matĉon")
("find text" "trovi tekston")
("finished collecting symbols documentation" "finis kolekti dokumentojn de simboloj")
("finnish" "finno")
("first" "unua")
("first chunk" "unua peceto")
("first contact" "unua kontakto")
("first difference" "unua diferenco")
("first error" "unua eraro")
("first field" "unua kampo")
("first indentation" "unua indentado")
("first item" "unua ero")
("first occurrence" "unua okazo")
("first page" "unua paĝo")
("first similar" "unua simila")
("first start" "unua komenco")
("fit to screen" "taŭgas por ekrano")
("fit to screen width" "taŭgas al larĝa ekrano")
("five columns" "kvin kolumnoj")
("fixed" "riparita")
("flag is off" "Flago estas malŝaltita")
("flag is on" "flago estas en")
("flat" "plata")
("flatten" "ebenigi")
("flexibility" "fleksebleco")
("flexibility factor for vertical spacing" "fleksebla faktoro por vertikala interspacigo")
("floating algorithm" "flosanta algoritmo")
("floating figure" "flosanta figuro")
("floating object" "flosanta objekto")
("floating phantom" "flosanta spektro")
("floating table" "flosanta tablo")
("focus" "fokuso")
("focus dependent icons" "Fokusaj dependaj ikonoj")
("fold" "faldi")
("fold all" "faldi ĉiujn")
("fold all fields" "plenigu ĉiujn kampojn")
("fold back" "faldi reen")
("fold input field" "faldebla ena kampo")
("folded" "falditaj")
("follow external links" "sekvu eksterajn ligojn")
("follow inverse links" "sekvu inversajn ligojn")
("font" "tiparo")
("font base size" "Grando de tiparo")
("font dpi" "tiparo dpi")
("font effects" "tipaj efikoj")
("font family" "tiparfamilio")
("font name" "tiparo nomo")
("font selector" "tipar-selektilo")
("font series" "tiparo")
("font shape" "tiparformo")
("font size" "tiparo")
("font type" "tiparo")
("font variant" "tiparo-varianto")
("fonts" "tiparoj")
("footer" "piedlinio")
("footnote" "piednoto")
("for" "por")
("for each" "por ĉiu")
("force reloading of translations" "devigi reŝarĝon de tradukoj")
("foreground" "malfono")
("foreign" "fremda")
("format" "formato")
("formatted and structured output" "Formata kaj strukturita eligo")
("formatted date" "formatita dato")
("formatting" "formatado")
("formula" "formulo")
("formula style" "formola stilo")
("forward" "antaŭen")
("forward replace" "antaŭen anstataŭi")
("forward search" "antaŭen serĉi")
("four columns" "kvar kolumnoj")
("four dots" "kvar punktoj")
("fourth" "kvara")
("fraction" "frakcio")
("fraktur" "fraktur")
("framed" "enkadrigita")
("french" "franca")
("from" "de")
("from center" "de centro")
("front matter" "antaŭa afero")
("full" "plena")
("full author list" "plena aŭtoro-listo")
("full manuals" "plenaj manlibroj")
("full screen mode" "plena ekrano-reĝimo")
("function" "funkcio")
("functional" "funkcia")
("further customization" "Plia personigo")
("future changes" "estontaj ŝanĝoj")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs venas sen ia ajn formo de laŭleĝa garantio")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs falas sub la ĝenerala publika permesilo de GNU")
("gap" "interspaco")
("garbage collection" "Rubo-kolektado")
("gaussian" "gaŭsa")
("gcd" "ĝcd")
("general" "ĝenerala")
("general architecture of TeXmacs" "ĝenerala arkitekturo de TeXmacs")
("general negation" "ĝenerala negado")
("general note" "ĝenerala noto")
("generated LaTeX document contains no errors" "generita LaTeX-dokumento enhavas neniujn erarojn")
("generated field" "generita kampo")
("generating font file" "generado de tipardosiero")
("generic" "genera")
("geometry" "geometrio")
("georgian" "georgian")
("german" "germano")
("get arity" "ekregas")
("get label" "akiri etikedon")
("get list with remote versions" "akiri liston per foraj versioj")
("getting started" "komenci")
("glossary" "glosaro")
("glossary entry" "glosara eniro")
("glue" "gluo")
("glue decorations" "gluaj ornamaĵoj")
("glyphs" "glifoj")
("gnaw" "ronko")
("gnawed" "ronkis")
("gnuPG command" "gnuPG-komando")
("gnuPG error: buffer encryption failed" "GnuPG-eraro: bufra ĉifrado malsukcesis")
("gnuPG error: cannot find suitable secret key to decrypt" "GnuPG-eraro: ne povas trovi taŭgan sekretan ŝlosilon por malĉifri")
("gnuPG requires name and email to have at least 5 characters" "gnuPG postulas nomon kaj retpoŝton havi almenaŭ 5 signojn")
("go" "iru")
("go to anchor" "iru ankri")
("go to anchor or float" "iru ankri aŭ flosigi")
("go to anchor or footnote" "iru al ankro aŭ piednoto")
("go to first similar tag" "iru al unua simila etikedo")
("go to float" "iru flosi")
("go to footnote" "iru al piednoto")
("go to last similar tag" "iru al lasta simila etikedo")
("go to next similar tag" "iru al sekva simila etikedo")
("go to previous similar tag" "iru al antaŭa simila etikedo")
("go to section" "iru al sekcio")
("gothic" "gotika")
("grain" "greno")
("granite" "granito")
("graphical effects" "grafikaj efektoj")
("graphical interface" "grafika interfaco")
("graphical interface font scale" "Grafika interfaca tiparo skalo")
("graphics" "grafikaĵoj")
("graphics geometry" "grafika geometrio")
("graphics grids" "grafikaj kradoj")
("grave" "tombo")
("greater" "pli granda")
("greater or equal" "pli granda aŭ egala")
("greek" "greka")
("greek letter" "greka letero")
("green" "verda")
("grey" "griza")
("greyed" "avida")
("grid" "krado")
("grid curves" "kradaj kurboj")
("grid points" "kradaj punktoj")
("grid-curve intersections" "krad-kurba intersekciĝoj")
("group" "grupo")
("group of objects" "grupo de objektoj")
("group/ungroup" "grupo / sengrupo")
("grouped" "grupigitaj")
("guarantee transparent source tracking" "Garantii travideblan spuran fonton")
("h modifier" "h modifilo")
("half wide" "duone larĝa")
("hand drawn" "mano tirita")
("happy typing" "feliĉa tajpado")
("has been aborted" "abortis")
("has completed its task" "kompletigis sian taskon")
("hat" "ĉapelo")
("header" "kaplinio")
("header and footer" "kaplinio kaj piedlinio")
("headers" "titoloj")
("hebrew" "hebrew")
("height" "alteco")
("height is exactly the specified height" "alteco estas ĝuste la specifita alteco")
("height is maximum of specified height and box height" "alteco estas maksimume specifita alteco kaj skatola alteco")
("height is minimum of specified height and box height" "alteco estas minimuma de specifita alto kaj skatola alteco")
("height magnification" "grandiga alteco")
("help" "helpo")
("help me" "helpu min")
("help us" "Helpu nin")
("here" "ĉi tie")
("hidden" "kaŝita")
("history" "historio")
("home" "hejmo")
("homepage" "hejmpaĝo")
("homoglyph substitutions" "homogenaj anstataŭaĵoj")
("horizontal" "horizontala")
("horizontal alignment" "horizontala vicigo")
("horizontal cell alignment" "horizontala ĉela vicigo")
("horizontal collapse distance" "horizontala kolapsa distanco")
("horizontal ink separation" "horizontala inko-apartigo")
("horizontal margins" "horizontalaj randoj")
("horizontal part" "horizontala parto")
("horizontal position" "horizontala pozicio")
("horizontal space" "horizontala spaco")
("horizontal table alignment" "horizontala tabela vicigo")
("horizontally align cell to the base" "horizontale vicigas ĉelon al la bazo")
("horizontally center the cell" "horizontale centri la ĉelon")
("how much longer may pages become" "kiom pli longe povas fariĝi paĝoj")
("how much shorter may pages become" "kiom pli mallongaj povas fariĝi paĝoj")
("huge" "grandega")
("hungarian" "hungara")
("hybrid command" "hibrida komando")
("hyperlink" "hiperligo")
("hyphenate as" "subteksto kiel")
("hyphenation" "ĉifono")
("icelandic" "icelandic")
("icon" "ikono")
("if" "se")
("if hyphenated" "Se hifenitaj")
("ignore" "ignori")
("image" "bildo")
("image links" "bildaj ligoj")
("impact" "efiko")
("implementation" "efektivigo")
("import" "importado")
("import bibliography" "importa bibliografio")
("import database entry" "Importa datumbazo eniro")
("import entries in buffer" "importaj eniroj en bufroj")
("import entry" "importa eniro")
("import file" "importodosiero")
("import selected database entries" "importi elektitajn datumbazajn enirojn")
("import selected entries" "importi elektitajn enskribojn")
("import selections as" "importaj elektoj kiel")
("import sessions" "importaj kunsidoj")
("import sophisticated objects as pictures" "importu kompleksajn objektojn kiel bildojn")
("imported bibliographic entries" "importitaj bibliografiaj enskriboj")
("improving the current implementation" "plibonigi la nunan efektivigon")
("in popup windows" "en ŝprucfenestron")
("inactive" "neaktiva")
("inanimated" "senanimaj")
("inch" "colo")
("include" "inkluzivas")
("include a document" "inkluzivas dokumenton")
("include file" "inkluzivas dosieron")
("inclusion into TeXmacs" "inkludo en TeXmacs")
("inclusions" "inkludoj")
("incomplete entries found to be filled out" "nekompletaj enskriboj troveblas")
("increase size" "pliigi grandecon")
("indent" "indent")
("indent paragraphs" "indentaj alineoj")
("indentation" "indentado")
("indentation flag" "flago de indentigo")
("index" "indekso")
("index entry" "indeksa eniro")
("index level" "indeksnivelo")
("indication" "indiko")
("informative flags" "informaj flagoj")
("initialize" "pravalori")
("ink here" "inko ĉi tie")
("ink in" "inko en")
("ink out" "inko ekstere")
("inline" "inline")
("inline arguments" "retaj argumentoj")
("inline code" "enreta kodo")
("inline content" "enreta enhavo")
("inline formula" "enreta formulo")
("inner bottom" "interna fundo")
("inner left" "interna maldekstro")
("inner right" "interna dekstra")
("inner top" "interna supro")
("input command" "eniga komando")
("input field" "eniga kampo")
("input mode" "eniga reĝimo")
("input options" "enigaj elektoj")
("insert" "enmetu")
("insert Pr" "enmetu Pr")
("insert a TeXmacs symbol" "Enmetu simbolon de TeXmacs")
("insert a big operator" "Enmetu grandan telefoniston")
("insert a binary operation" "enmetu binaran operacion")
("insert a binary relation" "enmetu binaran rilaton")
("insert a blackboard bold character" "enmetu nigran nigran karakteron")
("insert a bold calligraphic character" "enmetu aŭdacan kaligrafan karakteron")
("insert a bold character" "enmetu aŭdacan karakteron")
("insert a calligraphic character" "Enmetu kaligrafian karakteron")
("insert a computer program" "enmetu komputilan programon")
("insert a condition" "enmetu kondiĉon")
("insert a control flow instruction" "Enmetu kontrolan fluan instrukcion")
("insert a fraction" "enmetu frakcion")
("insert a fraktur character" "Enmetu frakturkarakteron")
("insert a gap" "enigi interspacon")
("insert a greek character" "enmetu grekan karakteron")
("insert a large left delimiter" "Enmetu grandan maldekstran limigilon")
("insert a large right delimiter" "Enmetu grandan dekstran limigilon")
("insert a large separator" "enmetu grandan apartigilon")
("insert a left subscript" "Enmetu maldekstran abonon")
("insert a link" "enmetu ligon")
("insert a list" "Enmetu liston")
("insert a miscellaneous symbol" "enmetu diversan simbolon")
("insert a multiple choice" "Enmetu multan elekton")
("insert a negation" "enmetu negacion")
("insert a new branch" "Enmetu novan branĉon")
("insert a new entry" "enmetu novan eniron")
("insert a new item" "Enmetu novan objekton")
("insert a note or a floating object" "Enmetu noton aŭ flosantan objekton")
("insert a numerical operation" "Enmetu nombran operacion")
("insert a picture" "Enmetu bildon")
("insert a prominent piece of text" "Enmetu elstaran tekston")
("insert a question" "Enmetu demandon")
("insert a root" "enmeti radikon")
("insert a script" "Enmetu skripton")
("insert a section block" "Enmetu sekcionbloko")
("insert a square root" "enmetu kvadratan radikon")
("insert a table" "enmetu tablon")
("insert a table or a matrix" "enmetu tablon aŭ matricon")
("insert a textual operation" "enmeti tekstan operacion")
("insert a textual operator" "enmeti tekstan operatoron")
("insert a wide symbol above" "Enmetu larĝan simbolon supre")
("insert a wide symbol below" "Enmetu larĝan simbolon sube")
("insert above" "enmetu supre")
("insert abstract" "enmetu abstraktadon")
("insert an" "enmetu")
("insert an accent" "enmetu akcenton")
("insert an answer" "enmetu respondon")
("insert an arrow" "enmetu sagon")
("insert an enunciation" "enigi enunton")
("insert an environment" "enmetu medion")
("insert an n" "enmetu n")
("insert an operation on tuples" "enmetu operacion sur la tuploj")
("insert annotation" "enigi komentaron")
("insert appendix" "enmeti apendicxon")
("insert arccos" "enmetu arkojn")
("insert arcsin" "enmetu arcsin")
("insert arctan" "enmetu arktanon")
("insert arg" "enmetu arg")
("insert argument" "enigi argumenton")
("insert author" "enmeti aŭtoron")
("insert automatically generated content" "enmetu aŭtomate generitan enhavon")
("insert below" "enmetu sube")
("insert big contour integral" "enmetu grandan konturon integran")
("insert big coproduct" "Enmetu grandan koprodukton")
("insert big direct sum" "enmetu grandan rektan sumon")
("insert big dotted point" "Enmetu grandan punktitan punkton")
("insert big integral" "enmetu grandan integralon")
("insert big intersection" "Enmetu grandan intersekciĝon")
("insert big logical and" "enmetu grandan logikon kaj")
("insert big logical or" "enmetu grandan logikon aŭ")
("insert big product" "Enmetu grandan produkton")
("insert big square union" "enmetu grandan kvadratan kuniĝon")
("insert big summation" "enmetu grandan resumon")
("insert big tensor product" "Enmetu grandan tensorprodukton")
("insert big union" "enigi grandan union")
("insert big union sum" "enmetu grandan sindikatan sumon")
("insert big vertical space" "enmetu grandan vertikalan spacon")
("insert chapter" "enmeti ĉapitron")
("insert column" "enmeti kolumnon")
("insert column to the left" "enmetu kolumnon maldekstren")
("insert column to the right" "enmetu kolumnon dekstren")
("insert copyright and license information" "Enmetu kopirajtajn kaj licencajn informojn")
("insert cos" "enmetu cos")
("insert cosh" "enmetu cosh")
("insert cot" "enmetu koton")
("insert coth" "enmetu liton")
("insert csc" "enmetu csc")
("insert deg" "enigi deg")
("insert det" "enigu det")
("insert dim" "enigi malhelan")
("insert dollar" "enmeti dolaron")
("insert equation" "enmeti ekvacion")
("insert executable markup" "Enmetu plenumeblan markadon")
("insert exp" "enmetu ekspon")
("insert explanatory item" "enmeti klarigan artikolon")
("insert field above" "enmetu kampon supre")
("insert field below" "enmetu kampon sube")
("insert fields" "enmeti kampojn")
("insert footnote" "Enmetu piednoton")
("insert formula" "enmeti formulon")
("insert gcd" "enmetu gcd")
("insert hom" "enmetu homon")
("insert horizontal interword space" "enmetu horizontalan interparolan spacon")
("insert image" "enmetu bildon")
("insert inactive markup" "enigu neaktivan markadon")
("insert inf" "enmetu inf")
("insert input field above" "Enmetu enan kampon supre")
("insert input field below" "Enmetu enan kampon sube")
("insert ker" "enigi ker")
("insert large delimiters" "enmetu grandajn limigilojn")
("insert last name" "enmetu familinomon")
("insert left" "enmetu maldekstran")
("insert lg" "enigu lg")
("insert lim" "enmetu limon")
("insert liminf" "enmetu liminfinon")
("insert limsup" "enmetu limsupon")
("insert ln" "enmetu ln")
("insert log" "enigi ŝtipo")
("insert macro" "enmetu makroon")
("insert mathematics" "enmetu matematikon")
("insert max" "enmetu maksimumon")
("insert medium horizontal space" "enmetu mezan horizontalan spacon")
("insert medium vertical space" "enmetu mezan vertikalan spacon")
("insert min" "enmetu min")
("insert missing invisible operators" "Enmetu mankajn nevideblajn telefonistojn")
("insert more names" "enigu pliajn nomojn")
("insert negative horizontal space" "enigu negativan horizontalan spacon")
("insert new item or number" "Enmetu novan eron aŭ numeron")
("insert new rows or columns" "enmetu novajn vicojn aŭ kolumnojn")
("insert or delete rows or columns" "Enmetu aŭ forigu vicojn aŭ kolumnojn")
("insert particle" "enmeti partiklon")
("insert plain text" "enmetu klaran tekston")
("insert right" "enmetu rajton")
("insert row" "enmeti vicon")
("insert row above" "enmetu vicon supre")
("insert row below" "enmetu vicon sube")
("insert sec" "enigi sek")
("insert section" "enmetu sekcion")
("insert sharp" "enmetu akran")
("insert similar above" "enmetu similan supre")
("insert similar below" "enmetu similan sube")
("insert similar block above" "enmetu similan blokon supre")
("insert similar block below" "Enmetu similan blokon sube")
("insert sin" "enmeti pekon")
("insert sinh" "enmeti sinh")
("insert small horizontal space" "enmetu malgrandan horizontalan spacon")
("insert small vertical space" "enmetu malgrandan vertikalan spacon")
("insert structural markup" "enmetu strukturan markadon")
("insert subsection" "enmeti subsekcion")
("insert subsubsection" "enmetu subsubsekcion")
("insert subtable" "enmetu subtekstojn")
("insert sup" "enigi sup")
("insert symbol documentation" "Enmetu simbolan dokumentaron")
("insert tan" "enmetu tan")
("insert tanh" "enigi tanh")
("insert template" "enmetu ŝablonon")
("insert text field" "enmetu tekstokampon")
("insert text field above" "Enmetu tekstokampon supre")
("insert text field below" "enmetu tekstokampon sube")
("insert thick horizontal space" "enmetu dikan horizontalan spacon")
("insert title" "enmetu titolon")
("insert title after name" "enmetu titolon post nomo")
("insert user interface related markup" "enmetu uzantinterfacan markadon")
("insert value" "enmeti valoron")
("inserting control points" "enigi kontrolpunktojn")
("integrate" "integri")
("interactive command" "interaga komando")
("interactive questions" "interagaj demandoj")
("intercharacter compression" "interkracira kunpremo")
("intercharacter stretching" "interĉara streĉado")
("interfacing" "interfacado")
("interfacing TeXmacs with other systems" "interfacado de TeXmacs kun aliaj sistemoj")
("interjection" "interjekcio")
("interline separation" "interlinia disiĝo")
("interline space" "interlinia spaco")
("internationalization" "internacieco")
("interparagraph space" "interpafara spaco")
("interrupt execution" "interrompa ekzekuto")
("interrupted" "interrompita")
("introduction" "enkonduko")
("invalid multi-paragraph selection" "malvalida plurpaĝa elekto")
("invalid renaming" "malvalida renomado")
("invert" "inversigi")
("inverted breve" "renversita breve")
("invisible" "nevidebla")
("invisible citation" "nevidebla citaĵo")
("invisible ending" "nevidebla fino")
("invisible newline" "nevidebla nova linio")
("invisible opening" "nevidebla malfermo")
("irish" "irlanda")
("is running" "funkcias")
("is tuple" "estas tuple")
("ispell does not respond" "ispell ne respondas")
("ispell is already busy" "ispell estas jam okupata")
("italian" "itala")
("italic" "kursivo")
("italic right" "kursiva rajto")
("itemize" "listigi")
("january" "januaro")
("japanese" "japana")
("join selected cells" "aliĝu al elektitaj ĉeloj")
("july" "julie")
("jump in" "salti en")
("june" "junio")
("junior" "junulo")
("justified" "pravigita")
("justify text" "pravigi tekston")
("keep evaluated expressions" "Konservu taksitajn esprimojn")
("keep local" "tenu lokan")
("keep remote" "tenu malproksime")
("keep track of source code" "konservu trakon de fontkodo")
("keep unfolded" "tenu neplenigitan")
("key" "ŝlosilo")
("keyboard" "klavaro")
("keyboard configuration" "klavara agordo")
("keyboard equivalent" "ekvivalenta klavaro")
("keyboard modifiers" "klavaro-modifiloj")
("keyboard shortcut" "klavara ŝparvojo")
("keymaps" "ŝlosilmapoj")
("keyword" "ŝlosilvorto")
("keywords" "kapvortoj")
("kill" "mortigi")
("known bugs" "konataj eraroj")
("label" "etikedo")
("landscape" "pejzaĝo")
("language" "lingvo")
("laptop presentations" "porteblaj prezentoj")
("large" "granda")
("large cells" "grandaj ĉeloj")
("large closing bracket" "granda ferma krampo")
("large delimiter" "granda limigilo")
("large displayed" "granda montrita")
("large displayed fraction" "granda montrata frakcio")
("large opening bracket" "granda malferma krampo")
("large separator" "granda apartigilo")
("large tables" "grandaj tabloj")
("last" "lasta")
("last difference" "lasta diferenco")
("last error" "lasta eraro")
("last field" "lasta kampo")
("last name" "familinomo")
("last occurrence" "lasta okazo")
("last page" "lasta paĝo")
("last similar" "lasta simila")
("latex command" "latex-komando")
("latin" "latin")
("layout" "aranĝo")
("lcm" "mcm")
("left" "maldekstre")
("left aligned" "maldekstre vicigita")
("left arrow" "maldekstra sago")
("left axis" "maldekstra akso")
("left baseline" "maldekstra bazlinio")
("left border" "maldekstra limo")
("left bottom" "maldekstra fundo")
("left cell border" "maldekstra ĉela limo")
("left cell padding" "maldekstra ĉela algluado")
("left center" "maldekstra centro")
("left click: add point; Right click: undo" "maldekstra klako: aldoni punkton; Dekstra alklako: malfari")
("left click: finish; Right click: undo" "maldekstra klako: fini; Dekstra alklaki: malfari")
("left click: new object" "maldekstra klako: nova objekto")
("left click: operate" "maldekstra klako: operacii")
("left down" "maldekstre malsupren")
("left margin" "maldekstra rando")
("left on even pages" "lasita sur eĉ paĝoj")
("left padding" "maldekstra kompletigo")
("left prime" "maldekstra primo")
("left slanted" "maldekstre deklinita")
("left subscript" "maldekstra subskribo")
("left superscript" "maldekstra superskribo")
("left surrounding" "maldekstre ĉirkaŭa")
("left table border" "maldekstra tablo-limo")
("left table padding" "maldekstra tabela surpasejo")
("left top" "maldekstra supro")
("left up" "maldekstre supren")
("left-right arrow" "maldekstre-dekstra sago")
("leftwards" "maldekstre")
("legal" "laŭleĝa")
("lemma" "lemo")
("length" "longo")
("less" "malpli")
("less or equal" "malpli aŭ egala")
("let the environment float" "lasu la medion flosi")
("letter" "letero")
("license" "licenco")
("light" "malpeza")
("light grey" "helgriza")
("limitations" "limigoj")
("limits" "limoj")
("line" "linio")
("line break" "linio-paŭzo")
("line breaking" "linio rompado")
("line stretch" "linio streĉi")
("line wrapping" "linioparto")
("linear 2D" "lineara 2D")
("linear algebra" "lineara algebro")
("lines around" "linioj ĉirkaŭ")
("link" "ligilo")
("link image" "ligila bildo")
("link image and copies as" "ligu bildon kaj kopias kiel")
("link image as" "ligila bildo kiel")
("link mode" "ligreĝimo")
("link to URL" "ligilo al URL")
("linking tool" "liga ilo")
("list" "listo")
("list of figures" "listo de figuroj")
("list of tables" "listo de tabloj")
("live" "vivas")
("live input-output" "rekta enigo-eligo")
("load" "ŝarĝo")
("load LaTeX file" "ŝargi LaTeX-dosieron")
("load TeX file" "ŝarĝu TeX-dosieron")
("load TeXmacs file" "Ŝargi TeXmacs-dosieron")
("load TeXmacs style file" "Ŝargi TeXmacs-stilon-dosieron")
("load a file" "ŝargi dosieron")
("load buffer" "buŝa ŝarĝo")
("load file" "ŝargi dosieron")
("load help file" "Ŝargi helpo-dosieron")
("load html file" "ŝargi html-dosieron")
("load image" "ŝargi bildon")
("load in new window" "Ŝarĝi en nova fenestro")
("load latex file" "ŝarĝu lateksan dosieron")
("load more recent autosave file" "ŝarĝu pli freŝan aŭtomatan dosieron")
("load remote file" "ŝarĝi malproksiman dosieron")
("load tex file" "ŝarĝi tekstodosieron")
("load verbatim file" "ŝarĝi verbatim-dosieron")
("loaded" "ŝarĝita")
("loading" "ŝarĝo")
("local entries" "lokaj enskriboj")
("loci" "loci")
("locus" "lokuso")
("locus rendering" "Locus-bildigo")
("logarithm" "logaritmo")
("logarithmic" "logaritma")
("logarithmic base" "logaritma bazo")
("logarithms" "logaritmoj")
("logging in" "ensalutado")
("logical and" "logika kaj")
("logical implication" "logika implikaĵo")
("logical not" "logike ne")
("logical or" "logika aŭ")
("login" "ensaluto")
("logout" "forigo")
("long" "longa")
("long macro" "longa makro")
("long text" "longa teksto")
("look and feel" "aspektu kaj sentu")
("look for more fonts" "serĉu pli da tiparoj")
("look up" "rigardu supren")
("loops" "bukloj")
("lower border" "malsupra limo")
("m modifier" "m modifilo")
("macro" "makro")
("macro argument" "makro-argumento")
("macro definition" "makro-difino")
("macro name" "makro-nomo")
("macros" "makrooj")
("magenta" "magenta")
("magic" "magio")
("magnification" "grandigo")
("magnified" "grandigita")
("magnify horizontally" "grandigi horizontale")
("magnify vertically" "grandigi vertikale")
("main" "ĉefa")
("main icon bar" "ĉefa ikono-stango")
("main presentation style" "ĉefa prezenta stilo")
("major changes" "gravaj ŝanĝoj")
("make a letter environment" "kreu letersekcion")
("make a multi-slide presentation" "Faru plurligan prezenton")
("make a page insertion" "Fari paĝon-enmeton")
("make a subscript" "fari abonon")
("make a superscript" "Faru superskripton")
("make acute" "akrigas")
("make bar" "fari stango")
("make check" "fari ĉekon")
("make floating" "fari flosadon")
("make fraction" "fari frakcion")
("make grave" "fari tombon")
("make hat" "fari ĉapelon")
("make label" "fari etikedon")
("make link" "fari ligon")
("make negation" "fari negacion")
("make non floating" "fari ne flosante")
("make page reference" "fari paĝon-referencon")
("make reference" "fari referencon")
("make square root" "fari kvadratan radikon")
("make tilde" "fari tilde")
("make title" "fari titolon")
("make vector" "fari vektoron")
("making donations" "farante donacojn")
("manila paper" "manila papero")
("manual" "manlibro")
("map arguments" "mapaj argumentoj")
("map to" "mapo al")
("march" "marŝo")
("marginal note" "marĝena noto")
("margins" "randoj")
("margins as on paper" "randoj kiel sur papero")
("margins from width" "randoj de larĝo")
("margins on paper" "randoj sur papero")
("margins on screen" "randoj sur ekrano")
("marked" "markita")
("master" "mastro")
("master file" "majstra dosiero")
("material" "materialo")
("math" "matematiko")
("math font" "matematika tiparo")
("math font family" "matematika tipfamilio")
("math font series" "matematika tiparo")
("math font shape" "matematika tiparo")
("mathematical" "matematiko")
("mathematical and customized input" "matematikaj kaj personecigitaj enigoj")
("mathematical font" "matematika tiparo")
("mathematical formulas" "matematikaj formuloj")
("mathematical input" "matematika enigo")
("mathematical output" "matematika eligo")
("mathematical typesetting" "Matematika kompostado")
("mathematics" "matematiko")
("matrices" "matricoj")
("matrix" "matrico")
("maximal" "maksimumo")
("maximal cell height" "maksimuma ĉela alteco")
("maximal clustering" "maksimuma agregado")
("maximal number of columns" "maksimuma nombro de kolonoj")
("maximal number of rows" "maksimuma nombro de vicoj")
("maximal table height" "maksimuma alteco de tablo")
("maximal table width" "maksimuma larĝa tablo")
("maximum" "maksimumo")
("maximum mode" "maksimuma reĝimo")
("may" "eble")
("meander" "meandro")
("medium" "meza")
("medium skip" "meza skipo")
("meminfo" "meminfo")
("memory" "memoro")
("memory usage" "memora uzado")
("menu" "menuo")
("merge" "kunfandi")
("merge lines into paragraphs unless separated by blank lines" "kunfandi liniojn en alineojn se ne apartigitaj per malplenaj linioj")
("messages" "mesaĝoj")
("messy" "malorda")
("meta data" "meta-datumoj")
("meta key" "metaŝlosilo")
("metadata" "metadatumoj")
("metal" "metalo")
("middle" "meza")
("middle baseline" "meza bazlinio")
("minimal" "minimumo")
("minimal cell height" "minimuma ĉela alteco")
("minimal cell width" "minimuma larĝa ĉelo")
("minimal line separation" "minimuma linia apartigo")
("minimal number of columns" "minimuma nombro da kolumnoj")
("minimal number of rows" "minimuma nombro da vicoj")
("minimal table height" "minimuma alteco de tablo")
("minimal table width" "minimuma larĝa tablo")
("minimum" "minimumo")
("minimum mode" "minimuma reĝimo")
("minus" "minus")
("mirror" "spegulo")
("miscellaneous" "diversspecaj")
("miscellaneous features" "diversaj aranĝoj")
("miscellanous" "miskolora")
("mod" "mod")
("mode" "reĝimo")
("mode dependent icons" "reĝimaj dependaj ikonoj")
("modifier" "modifilo")
("modify cell alignment" "modifi celomodelon")
("modify cell border" "modifi ĉelan limon")
("modify cell padding" "modifi ĉelajn kompletigojn")
("modify cell size" "modifi ĉelgrandecon")
("modify remote live document" "modifi forajn dokumentojn")
("modify table border" "modifi tablodomon")
("modify table padding" "modifi tabulplenumadon")
("module" "modulo")
("mongolian" "mongola")
("monospaced" "monospacita")
("more information about GNU TeXmacs can be found in the Help" "Pli da informoj pri GNU TeXmacs troveblas en la Helpo")
("more information about GNU TeXmacs can be found in the Help->About menu" "Pli da informoj pri GNU TeXmacs troveblas en la Helpo-> Pri la menuo")
("more information about GNU TeXmacs can be found in the help" "Pli da informoj pri GNU TeXmacs troveblas helpe")
("mosaic" "mozaiko")
("motion" "moviĝo")
("mouse over object" "muso super objekto")
("move" "movi")
("move down" "malsupreniru")
("move object" "movi objekton")
("move objects" "movi objektojn")
("move over object on which to operate" "moviĝu super objekto, sur kiu operacii")
("move to the right when finished" "movu dekstren kiam finiĝis")
("move up" "moviĝu supren")
("multiline" "multilinio")
("multiline input" "multilinea enigo")
("multiple choice" "multobla elekto")
("multiple root" "multobla radiko")
("multiplication" "multiplikado")
("mutator tags" "mutator-etikedoj")
("my documents" "miaj dokumentoj")
("n-th" "n-th")
("n-th root" "n-th-radiko")
("name" "nomo")
("navigation options" "navigaj elektoj")
("negation" "negado")
("never" "neniam")
("new" "nova")
("new account" "nova konto")
("new bibliography dialogue" "nova bibliografia dialogo")
("new buffer" "nova bufro")
("new column" "nova kolumno")
("new document" "nova dokumento")
("new double page" "nova duobla paĝo")
("new double page before" "nova duobla paĝo antaŭe")
("new entry" "nova eniro")
("new identity" "nova identeco")
("new item" "nova ero")
("new line" "nova linio")
("new locus" "nova loko")
("new macro" "nova makro")
("new number" "nova numero")
("new page" "nova paĝo")
("new page before" "nova paĝo antaŭe")
("new paragraph" "nova alineo")
("new passphrase" "nova pasfrazo")
("new remote directory" "nova fora dosierujo")
("new remote file" "nova fora dosiero")
("new roman" "nova romano")
("new row" "nova vico")
("new style fonts" "novaj stilaj tiparoj")
("new style page breaking" "Nova stilo-paĝo rompanta")
("new table" "nova tablo")
("new version" "nova versio")
("new window" "nova fenestro")
("newer version" "pli nova versio")
("next" "sekva")
("next chunk" "sekva peco")
("next difference" "sekva diferenco")
("next error" "sekva eraro")
("next field" "sekva kampo")
("next line" "sekva linio")
("next occurrence" "sekva okazo")
("next screen" "sekva ekrano")
("next similar" "sekva simila")
("no changes need to be saved" "ne necesas konservi ŝanĝojn")
("no clustering" "neniu grupigo")
("no completions" "neniuj finaĵoj")
("no dictionary for" "neniu vortaro por")
("no errors have been corrected" "neniuj eraroj estis korektitaj")
("no first indentation" "neniu unua indentado")
("no grid" "neniu krado")
("no indentation" "neniu indentado")
("no line break" "neniu linio-paŭzo")
("no matches found" "neniuj trovitaj matĉoj")
("no matches found for" "ne trovitaj matĉoj por")
("no more matches for" "ne plu kongruas por")
("no more redo information available" "Ne plu rehavas informojn haveblajn")
("no more undo information available" "Ne plu malfari informojn haveblajn")
("no name" "neniu nomo")
("no new public key in document" "neniu nova publika ŝlosilo en dokumento")
("no page break" "neniu paĝo-paŭzo")
("no page break after" "Neniu paŭzo post")
("no page break before" "neniu paĝo-paŭzo antaŭ")
("no page numbers" "neniuj paĝaj numeroj")
("no parent" "neniu gepatro")
("no selection" "neniu elekto")
("no spelling errors" "neniuj ortografiaj eraroj")
("no spelling errors found in text" "ne trovitaj ortografiaj eraroj en teksto")
("no style" "neniu stilo")
("none" "neniu")
("normal" "normala")
("normal loci" "normalaj locioj")
("norwegian" "norvega")
("not" "ne")
("not allowed to remove home directory" "ne rajtas forigi hejman dosierujon")
("not connected to server" "ne konektita al servilo")
("not equal" "ne egalas")
("not found" "ne trovita")
("not yet implemented" "ankoraŭ ne efektivigita")
("notation" "notacio")
("note" "noto")
("notebook" "kajero")
("november" "novembro")
("number" "numero")
("number equation" "ekvacio de nombroj")
("number of columns" "nombro de kolumnoj")
("number of polar steps" "nombro de polusaj paŝoj")
("number of subunit steps" "nombro de subaj paŝoj")
("numbered equation" "numerita ekvacio")
("numbered equations" "numeritaj ekvacioj")
("numbering" "numerado")
("numerator" "numeratoro")
("numeric" "numeralo")
("numeric spreadsheet" "nombra kalkultabelo")
("objectives" "celoj")
("occurrences" "okazoj")
("october" "oktobro")
("odd page" "nepara paĝo")
("odd page footer" "nepara paĝo-paĝo")
("odd page header" "nepara paĝo-kaplinio")
("odd page left margin" "nepara paĝo maldekstra rando")
("odd page margin" "nepara paĝo-marĝeno")
("odd page right margin" "nepara paĝo dekstra rando")
("odd page shift" "nepara paĝo-ŝanĝo")
("odd page text" "nepara paĝo-teksto")
("odd pages" "neparaj paĝoj")
("of fingerprint" "de fingrospuro")
("off" "malŝaltita")
("ok" "bone")
("old english" "malnova angla")
("old slavonic" "malnova slavona")
("old style" "malnova stilo")
("old version" "malnova versio")
("older version" "pli malnova versio")
("on" "sur")
("on cells" "sur ĉeloj")
("on columns" "sur kolonoj")
("on entire table" "sur tuta tablo")
("on rows" "sur vicoj")
("on the footer" "sur la piedlinio")
("on your system and set it up from the \"Security\" tab" "sur via sistemo kaj agordu ĝin el la langeto \"Sekureco\"")
("one column" "unu kolumno")
("one error has been corrected" "Unu eraro estas korektita")
("one lower case letter, one non alpha-numeric symbol" "Unu minuskla litero, unu ne alfa-numera simbolo")
("one numeric character, one upper case letter" "unu nombra signo, unu majuskla litero")
("one spelling error has been corrected" "Korektita eraro")
("online documentation" "interreta dokumentado")
("online help" "interreta helpo")
("only convert changes when re-importing" "nur konvertu ŝanĝojn kiam reimportas")
("only convert changes with respect to imported version" "konvertas nur ŝanĝojn koncerne importitan version")
("only convert changes with respect to tracked version" "Konvertas nur ŝanĝojn koncerne spuritan version")
("only implemented for complete subtrees" "efektivigita nur por kompletaj subretoj")
("only inline tags" "nur inline etikedoj")
("only keep folded" "tenu nur falditajn")
("only keep unfolded" "tenu nur ne disfaldita")
("only show semantic focus" "nur montras semantikan fokuson")
("opacity" "opakeco")
("open" "malfermita")
("open a new buffer" "malfermu novan bufron")
("open bibliography" "malferma bibliografio")
("open identities" "malfermaj identecoj")
("open in new window" "malfermi en nova fenestro")
("open key manager" "malfermita ŝlosila direktisto")
("open licence agreement" "Malkaŝa licenca interkonsento")
("open mailbox" "malferma poŝtaŭto")
("open module browser" "retumilo de malfermita modulo")
("open new window" "Malfermi novan fenestron")
("open symbol browser" "Malferma simbola retumilo")
("open tool in separate window" "Malferma ilo en aparta fenestro")
("opening" "malfermo")
("operation mode" "operaciumo")
("operation on named selection" "operacio sur nomita selektado")
("operation on primary selection" "operacio pri primara selektado")
("operation on secondary selection" "operacio sur malĉefa elekto")
("operation on ternary selection" "operacio sur ternaria elekto")
("optical" "optika")
("option" "eblo")
("options" "elektoj")
("or" "aŭ")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "aŭ donu la kompletan vojon al la \"gpg\" aŭ \"gpg2\" komando")
("orange" "oranĝa")
("order" "ordo")
("ordinary symbol" "ordinara simbolo")
("orientation" "orientiĝo")
("origin" "origino")
("original welcome message" "Originala bonvena mesaĝo")
("ornamented" "ornamita")
("other" "aliaj")
("other login" "alia ensaluto")
("other package" "alia pakaĵo")
("other pages" "aliaj paĝoj")
("other projects" "aliaj projektoj")
("other style" "alia stilo")
("outer bottom" "ekstera fundo")
("outer left" "ekstera maldekstro")
("outer right" "ekstera rajto")
("outer top" "ekstera supro")
("outline" "streko")
("outlined" "skizita")
("outlined emboss" "skizita koverto")
("outlined engrave" "skizita gravuraĵo")
("outlined roman" "skizita romano")
("output options" "eligaj elektoj")
("oval" "ovala")
("over" "super")
("overbrace" "overbrace")
("overlap" "interkovri")
("overlay" "tegmento")
("overlays" "interkovroj")
("overline" "superregulo")
("overlined" "superregita")
("overview of the scheme extension language" "Superrigardo de la lingvo-etenda lingvo")
("padded" "englutita")
("padding" "kompletigo")
("page" "paĝo")
("page background" "paĝo-fono")
("page bottom margin" "Paĝa funda marĝeno")
("page break" "paĝo-paŭzo")
("page break after" "Paŭzo-paŭzo post")
("page break before" "Paĝo-paŭzo antaŭ")
("page breaking algorithm" "algoritmo por rompi paĝojn")
("page height" "Paĝa alteco")
("page insertion" "paĝo-enmeto")
("page layout" "paĝo-aranĝo")
("page number" "paĝo-numero")
("page number rendering" "Bildigo de Paĝa numero")
("page number text" "paĝo-numero-teksto")
("page numbering" "Paĝa numerado")
("page reference" "paĝo-referenco")
("page rendering" "paĝo-bildigo")
("page right margin" "Paĝa dekstra marĝeno")
("page setup" "paĝo-aranĝo")
("page top margin" "Paĝa supra marĝeno")
("page type" "Paĝa tipo")
("page width" "paĝo larĝo")
("palette" "paleto")
("panorama" "panoramo")
("paper" "papero")
("paper type" "papera tipo")
("papyrus" "papiruso")
("paragraph" "alineo")
("paragraph mode" "alinereĝimo")
("paragraph width" "alinea larĝo")
("paragraphs" "alineoj")
("parametric curve" "parametrika kurbo")
("parametric surface" "parametrika surfaco")
("parenthesis" "krampoj")
("parenthesized" "krampita")
("part" "parto")
("particle" "ero")
("passphrase encryption" "pasfrasa ĉifrado")
("passphrase wallet facilities are not currently available" "pasfrazaj monujo ne estas nuntempe haveblaj")
("passphrases are expected to have at least: 8 characters" "pasfrazoj atendas almenaŭ: 8 signojn")
("passphrases mismatch" "Senpaŝaj pasfrazoj")
("past changes" "pasintaj ŝanĝoj")
("paste" "alglui")
("paste from" "alglui el")
("paste text" "alglui tekston")
("pastel" "pastel")
("path" "pado")
("pattern" "padrono")
("pause" "paŭzo")
("pen width" "pluma larĝo")
("perform operations on cells" "plenumi operaciojn sur ĉeloj")
("perform operations on columns" "plenumu operaciojn sur kolumnoj")
("perform operations on entire table" "plenumu operaciojn sur tuta tablo")
("perform operations on rows" "plenumi operaciojn sur vicoj")
("permanent" "permanenta")
("permanent footer" "permanenta piedlinio")
("permanent header" "permanenta kaplinio")
("permanently add to dictionary" "konstante aldoni al vortaro")
("permanently insert into dictionary" "konstante enmeti vortaron")
("permissions" "permesoj")
("person" "persono")
("personal dictionary has been modified" "persona vortaro estis modifita")
("phantasy" "fantasmo")
("phantom" "spektro")
("phantoms" "fantomoj")
("philosophy" "filozofio")
("phoenician" "fenikisto")
("phonetic" "fonetika")
("physics and astronomy class" "fizika kaj astronomia klaso")
("picture" "bildo")
("pine" "pino")
("pink" "rozkolora")
("plain" "ebenaĵo")
("plain block" "ebena bloko")
("plain boxes" "ebenaj skatoloj")
("plain circles" "eblaj rondoj")
("plain tabular" "ebena tabelaro")
("planned changes" "planitaj ŝanĝoj")
("plans for the future" "planoj por la estonteco")
("play" "teatraĵo")
("play animation" "lud-kuraĝigo")
("please" "bonvolu")
("please install GnuPG software from https://www.gnupg.org" "bonvolu instali programon GnuPG de https://www.gnupg.org")
("please wait" "bonvolu atendi")
("plot" "intrigo")
("plug-ins" "kromprogramoj")
("plugin" "kromaĵo")
("plugins" "kromprogramoj")
("plural" "pluralo")
("plus" "plus")
("point" "punkto")
("polar" "polusa")
("polish" "poluro")
("polygon" "plurlatero")
("pop server settings" "pop-servaj agordoj")
("porting TeXmacs to other platforms" "portante TeXmacojn al aliaj platformoj")
("portrait" "portreto")
("portuguese" "portugala")
("position" "pozicio")
("position float" "pozicio flosas")
("position floating object" "pozicio flosanta objekto")
("position of marginal note" "pozicio de marĝena noto")
("position the table" "poziciigu la tablon")
("poster formats" "afiŝformatoj")
("poster theme" "afiŝa temo")
("postfix" "postfiksado")
("postscript" "postscript")
("postscript image" "postscripta bildo")
("pre-alpha release" "antaŭ-alfa-liberigo")
("preamble" "enkonduko")
("preamble mode" "enkondukoreĝimo")
("preferences" "preferoj")
("preferences for editing mathematical formulas" "preferoj por redaktado de matematikaj formuloj")
("preferences for tag" "preferoj por etikedo")
("prefix" "prefikso")
("presentation" "prezento")
("presentation mode" "prezentreĝimo")
("presentation tag" "prezenta etikedo")
("presentation tool" "prezenta ilo")
("preserve" "konservi")
("preserve tags" "konservi etikedojn")
("pretty tree output" "bela arba eligo")
("preview" "antaŭvido")
("preview before printing" "antaŭrigardo antaŭ presado")
("preview command" "antaŭrigarda komando")
("preview with ghostview" "antaŭvido kun fantomrigardo")
("previous" "antaŭa")
("previous difference" "antaŭa diferenco")
("previous error" "antaŭa eraro")
("previous field" "antaŭa kampo")
("previous occurrence" "antaŭa okazo")
("previous screen" "antaŭa ekrano")
("previous similar" "antaŭa simila")
("primary" "primara")
("prime" "unua")
("primitive or macro" "primitiva aŭ makroa")
("print" "presaĵo")
("print all" "presi ĉiujn")
("print all to file" "Presi ĉiujn al dosiero")
("print buffer" "presa bufro")
("print buffer to file" "Presi bufron al dosiero")
("print page selection" "presita paĝo-elekto")
("print page selection to file" "presita paĝo-elekto al dosiero")
("print to file" "presi al dosiero")
("print to postscript file" "presi al postskriba dosiero")
("printer" "presilo")
("printer dpi" "presilo dpi")
("printer setup" "presilo-aranĝo")
("printing command" "presanta komando")
("problem" "problemo")
("professional" "profesia")
("prog" "prog")
("prog font" "prog-tiparo")
("prog font family" "prog-fontfamilio")
("prog font series" "prog-tipo-serio")
("prog font shape" "prog-fontformo")
("program" "programo")
("program bracket matching" "Program-krampa kongruado")
("program bracket selections" "programaj krampaj elektoj")
("program commands" "programkomandoj")
("program font" "programa tiparo")
("program interface for buffer management" "programinterfaco por bufro-administrado")
("program mode" "programa reĝimo")
("programming" "programado")
("programming routines for editing documents" "programaj rutinoj por redaktado de dokumentoj")
("progressive" "progresema")
("project" "projekto")
("projects" "projektoj")
("prologue" "antaŭparolo")
("prominent" "elstara")
("prompt on scripts" "prompto pri skriptoj")
("prompts and default input" "promesoj kaj defaŭlta enigo")
("proof" "pruvo")
("proportional" "proporcia")
("proportional typewriter" "proporcia tajpilo")
("proposition" "propono")
("provoke C++ error" "provokas C ++ eraron")
("provoke menu error" "provokas eraran menuon")
("provoke scheme error" "Provoki skemon-eraron")
("pseudo code" "pseŭdokodo")
("public key encryption" "publika ŝlosila ĉifrado")
("public keys" "publikaj ŝlosiloj")
("pulse" "pulso")
("qt GUI only, sorry. Use \"Export selection\"" "QT GUI nur, pardonu. Uzu \"Eksporti selektadon\"")
("qt-widgets" "qt-widgets")
("quantifier" "kvantigilo")
("quasi" "kvazaŭ")
("query replace" "enketo anstataŭas")
("question" "demando")
("questions only" "nur demandoj")
("questions with answers" "demandoj kun respondoj")
("quick evaluation of formulas" "rapida taksado de formuloj")
("quit" "eksiĝinta")
("quotation" "citaĵo")
("quote" "citaĵo")
("range" "gamo")
("rank" "rango")
("raw" "kruda")
("really close it" "vere fermas ĝin")
("really delete user identity" "vere forigi uzantidentecon")
("really huge" "vere grandega")
("really quit" "vere forlasis")
("really tiny" "vere eta")
("rebuild translations file" "rekonstrui dosieron de tradukoj")
("recent" "lastatempa")
("recent documents" "freŝaj dokumentoj")
("recipients" "ricevantoj")
("recognize" "rekoni")
("recover autosave file" "reakiri aŭtomatan dosieron")
("rectangular" "rektangula")
("red" "ruĝa")
("redo" "refari")
("redo undone changes" "refari malfaritajn ŝanĝojn")
("reduce" "redukti")
("reduce bottom margin by" "Redukti malsupran randon per")
("reduce left margin by" "redukti maldekstran randon per")
("reduce margins" "redukti randojn")
("reduce right margin by" "Redukti dekstran marĝenon per")
("reduce top margin by" "Redukti pintan marĝenon per")
("reduce trigonometric functions" "Redukti trigonometriajn funkciojn")
("reduced margins" "reduktitaj randoj")
("reduction even page margin" "Redukto de eĉ paĝo-marĝeno")
("reduction odd page margin" "redukto nepara paĝo-marĝeno")
("reduction page bottom margin" "Redukta paĝo-marĝeno")
("reduction page right margin" "Redukta paĝo dekstra marĝeno")
("reduction page top margin" "Redukta paĝo-supra marĝeno")
("reference" "referenco")
("reference guide" "referenca gvidilo")
("reference guide for the TeXmacs primitives" "Referenca Gvidilo por la primitivuloj de TeXmacs")
("reference guide for the standard TeXmacs styles" "referenca gvidilo por la normaj TeXmacs-stiloj")
("references" "referencoj")
("regenerate" "regeneriĝi")
("register file" "registra dosiero")
("regular" "regula")
("relate" "rilatas")
("relation" "rilato")
("release" "liberigo")
("release left button: finish editing" "liberigi maldekstran butonon: fini redaktadon")
("reload" "reŝargi")
("remark" "rimarko")
("remote" "fora")
("remote connections" "foraj ligoj")
("remote control" "fora kontrolo")
("remote controllers with keyboard simulation" "foraj regiloj kun klavara simulado")
("remote directory" "fora adresaro")
("remote servers" "foraj serviloj")
("remote tool" "fora ilo")
("remove" "forigi")
("remove all output fields" "forigi ĉiujn elirajn kampojn")
("remove banner" "forigi rubandon")
("remove database entry" "forigi datumbazon")
("remove downwards" "forigu malsupren")
("remove entries" "forigi enskribojn")
("remove entry" "forigi eniron")
("remove field above" "forigi kampon supre")
("remove field below" "forigi kampon sube")
("remove fields" "forigi kampojn")
("remove folded" "forigu falditajn")
("remove input field" "forigi enan kampon")
("remove input field above" "forigi enan kampon supre")
("remove last field" "forigu lastan kampon")
("remove leftwards" "forigu maldekstren")
("remove link" "forigi ligon")
("remove next field" "forigu sekvan kampon")
("remove number" "forigi numeron")
("remove package" "forigi pakaĵon")
("remove previous field" "forigi antaŭan kampon")
("remove rightwards" "forigu dekstren")
("remove selected database entries" "forigu elektitajn datumbazojn")
("remove selected entries" "forigi elektitajn enskribojn")
("remove superfluous invisible operators" "forigu superfluajn nevideblajn telefonistojn")
("remove tag" "forigi etikedon")
("remove this branch" "forigu ĉi tiun branĉon")
("remove this switch" "forigu ĉi tiun ŝaltilon")
("remove unfolded" "forigi neplenumitan")
("remove upwards" "forigi supren")
("removed entries from database" "forigitaj enskriboj el datumbazo")
("removed entry from database" "forigita eniro el datumbazo")
("rename" "alinomi")
("rename section" "renomi sekcion")
("renumber this page" "renumeru ĉi tiun paĝon")
("repeat" "ripeti")
("repeat object" "ripetobjekto")
("replace" "anstataŭi")
("replace TeXmacs styles with no LaTeX equivalents" "anstataŭigu TeXmac-stilojn kun neniuj LaTeX-ekvivalentoj")
("replace all further occurrences" "anstataŭigu ĉiujn pluajn aperojn")
("replace by" "anstataŭigu per")
("replace one occurrence" "anstataŭigu unu okazon")
("replace toolbar" "anstataŭigu ilobregon")
("replace unrecognized styles" "anstataŭigu ne rekonitajn stilojn")
("replaced" "anstataŭita")
("replaced one occurrence" "anstataŭis unu aperon")
("reset" "restarigi")
("reset error counters" "restarigi erarojn")
("resize" "regrandigi")
("resize object" "regrandigi objekton")
("resize objects" "regrandigi objektojn")
("resized" "regrandigita")
("restart TeXmacs in order to let changes take effect" "rekomencu TeXmacs por lasi ŝanĝojn efiki")
("restart in order to let the new look and feel take effect" "rekomencu por lasi la novan aspekton kaj senti efikon")
("retain" "reteni")
("retime" "reĝimo")
("retina settings" "retaj agordoj")
("retrieve email" "retrovi retpoŝton")
("retrieve remote live document" "retrovu malproksiman vivan dokumenton")
("retrieved contents" "retrovitaj enhavoj")
("return" "reveno")
("reverse" "inversa")
("reverse ordering" "inversa ordigo")
("revert" "reverti")
("revert buffer" "revertu bufron")
("ridged paper" "kresta papero")
("right" "ĝuste")
("right aligned" "dekstre vicigita")
("right arrow" "dekstra sago")
("right baseline" "dekstra bazlinio")
("right border" "dekstra limo")
("right cell border" "dekstra ĉela limo")
("right cell padding" "dekstra ĉela kompletigo")
("right down" "dekstre sube")
("right margin" "dekstra rando")
("right on even pages" "ĝuste sur eĉ paĝoj")
("right padding" "dekstra kompletigo")
("right subscript" "ĝusta abono")
("right superscript" "dekstra superskribo")
("right surrounding" "dekstra ĉirkaŭaĵo")
("right table border" "dekstra tabla limo")
("right table padding" "dekstra tablo-kompletigo")
("right up" "dekstre supren")
("rightwards" "dekstre")
("rigid" "rigida")
("rigid box" "rigida skatolo")
("rigid horizontal" "rigida horizontalo")
("rigid space" "rigida spaco")
("romanian" "rumana")
("root" "radiko")
("rotate" "turni")
("rotate backward" "turni malantaŭen")
("rotate forward" "turni antaŭen")
("rotate objects" "turni objektojn")
("rough" "malglata")
("rough paper" "malglata papero")
("round" "ronda")
("round overbrace" "ronda superrapido")
("round underbrace" "ronda subaĵo")
("row" "vico")
("row above" "vico supre")
("row below" "vico sube")
("row contains glued items" "vico enhavas gluitajn artikolojn")
("rows" "vicoj")
("run" "kuri")
("run current file" "funkciigu aktualan dosieron")
("runic" "runic")
("running author" "kuranta aŭtoro")
("running title" "kuranta titolo")
("russian" "rusa")
("same names" "samaj nomoj")
("same screen margins as on paper" "samaj ekranaj randoj kiel sur papero")
("sample" "specimeno")
("sample text" "ekzempla teksto")
("sans serif" "sans serif")
("save" "ŝpari")
("save TeXmacs file" "konservi TeXmacs-dosieron")
("save TeXmacs style file" "konservu TeXmacs-stilon-dosieron")
("save as" "konservu kiel")
("save as LaTeX" "konservu kiel LaTeX")
("save as TeX" "konservu kiel TeX")
("save auxiliary data" "konservu helpajn datumojn")
("save buffer" "konservi bufron")
("save buffer as" "konservu bufron kiel")
("save entries" "konservi enskribojn")
("save entry" "konservi eniron")
("save file" "konservi dosieron")
("save html file" "konservi html-dosieron")
("save image" "konservi bildon")
("save image as" "konservi bildon kiel")
("save latex file" "konservu lateksan dosieron")
("save position" "konservi pozicion")
("save remote file" "konservi malproksiman dosieron")
("save tex file" "konservi tekstodosieron")
("save this buffer" "konservu ĉi tiun bufron")
("save verbatim file" "konservi verbatim-dosieron")
("saved" "konservita")
("saved modifications in database" "konservitaj modifoj en datumbazo")
("scheme command" "skema komando")
("scheme developers guide" "skemaj programistoj gvidas")
("scheme extensions" "skemaj etendoj")
("scheme interface for the graphical mode" "skema interfaco por la grafika reĝimo")
("screen" "ekrano")
("screen layout" "ekrana aranĝo")
("screen margins" "ekranaj randoj")
("screen rendering" "ekrano-bildigo")
("screens" "ekranoj")
("screenshot" "ekrankopio")
("script" "skripto")
("script above" "skripto supre")
("script below" "skripto sube")
("script script size" "skripto grandeco")
("script size" "skripta grando")
("scripting language" "skriptlingvo")
("scripts" "skriptoj")
("scripts not accepted" "skriptoj ne akceptitaj")
("search" "serĉo")
("search and replace" "serĉu kaj anstataŭigu")
("search results for" "serĉrezultoj por")
("search toolbar" "serĉila ilobreto")
("search words in my documents" "serĉvortoj en miaj dokumentoj")
("search words in the documentation" "serĉvortoj en la dokumentaro")
("search words in the source code" "serĉi vortojn en la fontkodo")
("searching" "serĉado")
("second" "dua")
("secondary" "malĉefa")
("secret keys" "sekretaj ŝlosiloj")
("section" "sekcio")
("sections" "sekcioj")
("security" "sekureco")
("see" "vidu")
("see documentation" "vidu dokumentadon")
("select a document style" "elektu dokumentan stilon")
("select a foreground color" "elektu antaŭan koloron")
("select a language" "elektu lingvon")
("select pen" "elekta plumo")
("select the action to be undertaken for each conflict" "elektu la agon por realigi por ĉiu konflikto")
("select view mode" "elektu vidmanieron")
("selected region" "elektita regiono")
("selection" "elekto")
("selections" "elektoj")
("semantic correctness" "semantika korekteco")
("semantic editing" "semantika redaktado")
("semantic selections" "semantikaj elektoj")
("semantics" "semantiko")
("seminar" "seminario")
("sending commands to TeXmacs" "sendantaj komandoj al TeXmacs")
("senior" "aĝulo")
("separation between lines" "disiĝo inter linioj")
("separation between paragraphs" "apartigo inter alineoj")
("separator" "apartigilo")
("september" "septembro")
("serb" "serbo")
("series" "serio")
("series|right" "serio | dekstra")
("serif" "serif")
("server" "servilo")
("session" "sesio")
("session commands" "sesioj ordonas")
("session name" "sesio nomo")
("session type" "sesio-tipo")
("sessions" "sesioj")
("set" "aro")
("set background color of cell" "agordita fonkoloro de ĉelo")
("set cell mode" "agordita ĉela reĝimo")
("set default" "agordita defaŭlta")
("set difference" "difinita diferenco")
("set extension center" "agordita etenda centro")
("set height" "agordita alteco")
("set height of cell" "agordita alteco de ĉelo")
("set intersection" "fiksita intersekciĝo")
("set margins" "fiksitaj randoj")
("set n" "aro n")
("set number of columns" "difinita nombro de kolumnoj")
("set number of rows" "difinita nombro de vicoj")
("set or get environment variables" "agordi aŭ akiri mediajn variablojn")
("set paragraph margins" "agordas alineajn marĝenojn")
("set paragraph mode" "agordita alinereĝimo")
("set printer dpi" "agordas presilon dpi")
("set printing command" "agordi presan komandon")
("set properties" "fiksitaj propraĵoj")
("set span" "agordita")
("set special cell properties" "agordas specialajn ĉelajn proprietojn")
("set special table properties" "agordas specialajn tabelajn proprietojn")
("set text width" "agordita larĝa teksto")
("set union" "fiksita kuniĝo")
("set user information" "agordi uzantinformojn")
("set width" "agordita larĝo")
("set width of cell" "agordita larĝo de ĉelo")
("settings" "agordoj")
("setup printer" "")
("seventh" "sepa")
("several equations" "pluraj ekvacioj")
("shadow" "ombro")
("shadowed" "ombro")
("shadowed raise" "ombra supreniro")
("shape" "formo")
("shift" "turno")
("shift-down" "malŝaltiĝo")
("shift-right" "majuskle")
("short" "mallonga")
("show" "spektaklo")
("show all parts" "Montri ĉiujn partojn")
("show current focus" "montras nunan fokuson")
("show full context" "montras plenan kuntekston")
("show header and footer" "montras kaplinion kaj piedlinion")
("show hidden" "Montri kaŝita")
("show key presses" "montru ŝlosilojn")
("show main document" "Montri ĉefan dokumenton")
("show memory usage" "montras memoruzon")
("show on screen" "Spektaklo sur ekrano")
("show one part" "montras unu parton")
("show panorama" "montras panoramon")
("show preamble" "spektakla enkonduko")
("show several parts" "montras plurajn partojn")
("show subunits" "montras subunuojn")
("show table cells" "montras tabelĉelojn")
("show timings" "spektaklaj tempoj")
("shrinking factor" "malpligrandiga faktoro")
("side tools" "flankaj iloj")
("signature" "subskribo")
("simple" "simpla")
("simplification" "simpligo")
("simplified evaluation of formulas" "simpligita taksado de formuloj")
("simplified menus" "simpligitaj menuoj")
("simplify" "simpligi")
("sine" "sino")
("sixth" "sesa")
("size" "grandeco")
("size limits" "grandecaj limoj")
("size tag" "grandgranda")
("skew" "deklivo")
("skip all" "saltu ĉiujn")
("slant" "deklivo")
("slanted" "deklinita")
("slashed fraction" "frakasita frakcio")
("slides" "lumbildoj")
("sloppy" "deklivo")
("slovene" "slovena")
("slow" "malrapida")
("slow decrease" "malrapida malkresko")
("slow increase" "malrapida kresko")
("small" "malgranda")
("small capitals" "malgrandaj ĉefurboj")
("small caps" "malgrandaj ĉapoj")
("small environment box" "malgranda medio-skatolo")
("small figure" "malgranda figuro")
("small focus" "malgranda fokuso")
("small inline" "malgranda linio")
("small inline fraction" "malgranda enreta frakcio")
("small skip" "malgranda skipo")
("small table" "malgranda tablo")
("smash" "frakasado")
("smooth" "glata")
("smooth end" "glata fino")
("smooth extremities" "glataj ekstremoj")
("smooth start" "glata komenco")
("snap" "kaptuko")
("snap distance" "akompana distanco")
("snap to curves" "enŝovo al kurboj")
("snap to grid" "alkroĉu al krado")
("snap to grid curve" "alkroĉi kradan kurbon")
("snap to intersections of curves" "kaptuko al intersekcoj de kurboj")
("snap to text borders" "kapti al tekstaj limoj")
("snap to text corners" "kapti al tekstaj anguloj")
("solution" "solvo")
("solution to exercise" "solvo por ekzerci")
("solution to problem" "solvo al problemo")
("solutions" "solvoj")
("sound" "sono")
("source" "fonto")
("source code" "fontkodo")
("source macros tool" "Fonta makro-ilo")
("source tags" "fonto-etikedoj")
("south" "sudo")
("south east" "sudoriente")
("space" "spaco")
("space bar in math mode" "spaco-stango en matematika reĝimo")
("space bar in text mode" "spaco-stango en teksta reĝimo")
("space between lines" "spaco inter linioj")
("space between paragraphs" "spaco inter alineoj")
("space stretchability" "spaca streĉebleco")
("spacing" "interspacigado")
("span" "interspaco")
("span over all columns" "interspaco super ĉiuj kolumnoj")
("spanish" "hispana")
("special" "speciala")
("special cell properties" "specialaj ĉelaj proprietoj")
("special functions" "specialaj funkcioj")
("special properties" "specialaj havaĵoj")
("special table properties" "specialaj tabelaj proprietoj")
("specific" "specifa")
("specific baseline" "specifa bazlinio")
("specify color alternation" "specifi alternadon de koloro")
("specify how to traverse the manual" "precizigi kiel trapasi la manlibron")
("specify semantics of a symbol or formula" "precizigu semantikon de simbolo aŭ formulo")
("specify the size of the table" "specifi la grandecon de la tablo")
("spell" "sorĉo")
("spell check" "literumilo")
("spell checking complete" "kompleta ortografio")
("spelling error" "erara ortografio")
("spelling errors have been corrected" "")
("spline" "spline")
("split" "disigo")
("split program" "disfendita programo")
("split session" "fendita sesio")
("square" "kvadrato")
("square overbrace" "kvadrata superrapido")
("square root" "kvadrata radiko")
("square underbrace" "kvadrata subaĵo")
("stack" "stako")
("standard" "normo")
("standard Output" "Norma Eligo")
("standard TeXmacs styles" "normaj TeXmacs-stiloj")
("standard environment variables" "normaj mediaj variabloj")
("standard formats" "normaj formatoj")
("standard fraction" "norma frakcio")
("star" "stelo")
("start" "komenco")
("start a new chapter" "komenci novan ĉapitron")
("start a new section" "komenci novan sekcion")
("start an interactive session" "komenci interagan sesion")
("start server" "starta servilo")
("statement" "deklaro")
("statistics" "statistikoj")
("status" "statuso")
("status bar" "status-stango")
("stop server" "haltiga servilo")
("storage" "stokado")
("store tracking information in LaTeX files" "vendejo pri spurado de informoj en LaTeX-dosieroj")
("stretch" "streĉado")
("stretch factor" "streĉa faktoro")
("stretchable" "streĉebla")
("stretchable horizontal" "streĉebla horizontalo")
("stretchable vertical" "streĉebla vertikalo")
("stretched" "etendita")
("strict Ascii" "strikta Ascii")
("strike through" "striko tra")
("stroke" "streko")
("strokes" "strekoj")
("strong" "forta")
("structural" "struktura")
("structured insert above" "strukturita enmeto supre")
("structured insert at the left" "strukturita enmeto maldekstre")
("structured insert at the right" "strukturita enmeto dekstre")
("structured insert below" "strukturita enmeto sube")
("structured remove downwards" "strukturita forigi malsupren")
("structured remove leftwards" "strukturita forigi maldekstren")
("structured remove rightwards" "strukturita forigo dekstre")
("structured remove upwards" "strukturita forigo supren")
("structured variant" "strukturita varianto")
("style" "stilo")
("style options" "stilaj opcioj")
("style parameters" "stilaj parametroj")
("styles" "stiloj")
("stylesheet language" "Stila folia lingvo")
("sub" "sub")
("subject" "temo")
("submenu" "submenuo")
("subparagraph" "subpaĝo")
("subscript" "abono")
("subscript below" "subskribo sube")
("subsection" "subsekcio")
("subsub" "subsub")
("subsubmenu" "subsubmenu")
("subsubsection" "subsubsekcio")
("subsubsubmenu" "subsubsubmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "subtable")
("subtitle" "subtitolo")
("subtraction" "subtraho")
("summarized" "resumita")
("summary" "resumo")
("summary of the principal TeXmacs tags" "resumo de la ĉefaj etikedoj de TeXmacs")
("superpose" "superpone")
("superposed" "superpona")
("superscript" "superskribo")
("superscript above" "superskribita supre")
("supported plug-ins" "subtenataj kromprogramoj")
("surface" "surfaco")
("swedish" "sveda")
("inflate" "ŝvelinta")
("swiss" "svisoj")
("switch" "ŝaltilo")
("switch to buffer" "ŝanĝi al bufro")
("switch to first" "ŝanĝi al unua")
("switch to formula style" "ŝanĝi al formula stilo")
("switch to last" "ŝanĝi ĝis daŭri")
("switch to next" "ŝanĝi al sekva")
("switch to previous" "ŝanĝi al antaŭa")
("switching and folding" "ŝaltado kaj faldiĝo")
("symbol" "simbolo")
("symbol properties not found" "simbolaj ecoj ne trovitaj")
("symbols" "simboloj")
("synchronize" "sinkronigi")
("synchronize bibliographic references" "sinkronigi bibliografiajn referencojn")
("synchronize with remote server" "sinkronigi kun fora servilo")
("synopsis" "sinopsis")
("system command" "sistema komando")
("system environment variables" "sistemaj mediaj variabloj")
("tab" "langeto")
("tab-completion" "langeto-kompletigo")
("tabbed" "langeto")
("table" "tablo")
("table breaking" "rompado de tablo")
("table command" "tabla komando")
("table height" "alteco de tablo")
("table of contents" "Enhavo")
("table properties" "tabloproprietoj")
("table width" "larĝa tablo")
("tables" "tabloj")
("tabular" "tabelaro")
("tabular material" "tabela materialo")
("tags with special rendering" "etikedoj kun speciala bildigo")
("tangent" "tangento")
("teXmacs DTD" "teXmacs DTD")
("teXmacs as an interface" "teXmacs kiel interfaco")
("teXmacs buffer expected" "buffer de TeXmacs atendita")
("teXmacs buffer on disk expected" "buffer de TeXmacs sur disko atendita")
("teXmacs extensions to scheme and utilities" "etendoj de TeXmacs al skemo kaj utilecoj")
("teXmacs fonts" "teXmacs-tiparoj")
("teXmacs macro" "teXmacs-makro")
("teXmacs notice" "avizo de TeXmacs")
("teXmacs package" "teXmacs-pakaĵo")
("teXmacs plugins" "teXmacs-kromaĵoj")
("teXmacs primitives" "teXmacs-primitivuloj")
("teXmacs style" "teXmacs stilo")
("teXmacs style files" "teXmacs-stildosieroj")
("ternary" "ternario")
("test" "testo")
("test routine" "testo rutino")
("testing tree-view" "testado de arbo-vido")
("tex" "tex")
("text" "teksto")
("text borders" "tekstaj limoj")
("text box style" "tekstokesto-stilo")
("text corners" "tekstaj anguloj")
("text font" "")
("text height correction" "teksta alteco-korekto")
("text width" "larĝa teksto")
("texts" "tekstoj")
("textual" "teksta")
("textual operator" "teksta telefonisto")
("textual spreadsheet" "teksta kalkultabelo")
("th century bc" "jarcenta jarcento")
("th root" "la radiko")
("thai" "taja")
("the TeXmacs authors" "la aŭtoroj de TeXmacs")
("the TeXmacs format" "la formato TeXmacs")
("the TeXmacs plug-in system" "la kromprogramo TeXmacs")
("the application did not send its usual startup banner" "La aplikaĵo ne sendis sian kutiman komencan rubandon")
("the application does not reply" "la apliko ne respondas")
("the application is already running" "la apliko jam funkcias")
("the boxes produced by the typesetter" "la skatoloj produktitaj de la tajpilo")
("the document has not been saved" "la dokumento ne konserviĝis")
("the graphical user interface" "la grafika uzantinterfaco")
("the leaves of TeXmacs trees" "la folioj de TeXmacs-arboj")
("the mycas example" "la mycas ekzemplo")
("the primitive TeXmacs constructs" "la primitivaj TeXmacs konstruas")
("the standard TeXmacs styles" "la normaj TeXmacs-stiloj")
("theme parameters" "temaj parametroj")
("theorem" "teoremo")
("there are unsaved documents" "estas ne konservitaj dokumentoj")
("these collected public keys will be definitely lost" "ĉi tiuj kolektitaj publikaj ŝlosiloj estos sendube perditaj")
("these public keys will be definitely lost" "ĉi tiuj publikaj ŝlosiloj estos sendube perditaj")
("these secret keys will be definitely lost" "ĉi tiuj sekretaj ŝlosiloj estos sendube perditaj")
("thicken" "dikigi")
("third" "tria")
("this" "ĉi")
("this column" "ĉi tiu kolumno")
("this document has been produced using" "ĉi tiu dokumento estis produktita per")
("this document has not been saved" "ĉi tiu dokumento ne konserviĝis")
("this line" "ĉi tiu linio")
("this page" "ĉi paĝo")
("this page footer" "ĉi tiu paĝo-paĝo")
("this page header" "ĉi tiu paĝo-kaplinio")
("this page number" "ĉi tiu paĝo-numero")
("this row" "ĉi tiu vico")
("this style specifies page margins in the TeX way" "ĉi tiu stilo specifas paĝajn randojn en la TeX-maniero")
("three columns" "tri kolumnoj")
("three dots" "tri punktoj")
("through popup windows" "tra ŝprucfenestroj")
("through the menus" "tra la menuoj")
("thumbnails" "bildetoj")
("tilda" "tilda")
("tilde" "tilde")
("time evolution" "evolua tempo")
("times" "fojoj")
("timings" "tempigoj")
("tiny" "eta")
("title" "titolo")
("title presentation options" "opcioj pri prezentado de titolo")
("title style" "titolo stilo")
("title suffix" "titana sufikso")
("titled block" "titolita bloko")
("to the left" "maldekstre")
("to the right" "dekstre")
("today" "hodiaŭ")
("toggle cell wrapping mode" "ŝalti ĉel-envolvan reĝimon")
("toggle here" "alternas ĉi tie")
("toggle off" "elŝalti")
("toggle on" "ŝanĝi")
("tolerant" "tolerema")
("tools" "iloj")
("top" "supro")
("top baseline" "supera bazlinio")
("top border" "supra limo")
("top cell border" "supra ĉela limo")
("top cell padding" "pinta ĉela ŝtopilo")
("top level" "supera nivelo")
("top margin" "supra marĝeno")
("top padding" "supra kompletigo")
("top table border" "supera tablo-limo")
("top table padding" "supra tablo-kompletigo")
("transform" "transformi")
("transform cell into subtable" "transformi ĉelon en subtekteblan")
("translate" "traduki")
("translations" "tradukoj")
("translations loaded" "tradukoj ŝarĝitaj")
("transpose" "transponi")
("traversal" "trairejo")
("traverse" "transversa")
("tree" "arbo")
("triangle" "triangulo")
("triangularize" "trianguli")
("trigonometric" "trigonometria")
("trigonometry" "trigonometrio")
("tuple" "tuple")
("turkish" "turka")
("turn off" "malŝalti")
("turn on" "ŝalti")
("tutorial" "lernilo")
("two columns" "du kolumnoj")
("two dots" "du punktoj")
("type" "tipo")
("type a latex command followed by" "tajpu lateksan komandon sekvitan de")
("type a latex command followed by return" "tajpu lateksan komandon sekvitan de reveno")
("type body" "tipo-korpo")
("type denominator" "tipo-nomanto")
("type numerator" "tipo-numeratoro")
("type script" "tajpa skripto")
("typesetted boxes" "tajpitaj skatoloj")
("typewriter" "tajpilo")
("typewriter small caps" "tajpaj malgrandaj ĉapoj")
("typing a simple text" "tajpante simplan tekston")
("typing simple texts" "tajpi simplajn tekstojn")
("ugaritic" "ugaritika")
("ukrainian" "ukraina")
("underbrace" "underbrace")
("underline" "substrekita")
("underlined" "substrekita")
("undo" "malfari")
("undo last changes" "Malfari lastajn ŝanĝojn")
("unevaluated argument" "senvalora argumento")
("unevaluated value" "nevalorita valoro")
("unfold" "disfaldi")
("unfold all" "disfaldi ĉiujn")
("unfold all fields" "disfaldas ĉiujn kampojn")
("unit" "unuo")
("unit length" "unuo-longo")
("unknown secret key fingerprint" "nekonata sekreta ŝlosila fingrospuro")
("unregistered file" "neregistrita dosiero")
("unroll" "malvolvi")
("unsecure script refused" "nesekura skripto rifuzis")
("unsupported link mode" "nesubtenita ligreĝimo")
("until" "ĝis")
("untitled block" "neligita bloko")
("up" "supren")
("up to date" "ĝisdatigita")
("update" "ĝisdatigo")
("update buffer" "ĝisdatiga bufro")
("update from web" "Ĝisdatigo de retejo")
("update image links" "Ĝisdatigi bildajn ligojn")
("update this buffer" "Ĝisdatigu ĉi tiun bufron")
("update web site" "Ĝisdatiga retejo")
("upight" "supren")
("upload" "alŝuto")
("upper border" "supra limo")
("upright" "Ĝusta")
("upwards" "supren")
("use CSS for more advanced formatting" "Uzu CSS por pli progresinta formatado")
("use MathML" "uzi MathML")
("use TeXmacs" "uzu TeXmacojn")
("use a black color" "uzi nigran koloron")
("use a blue color" "uzu bluan koloron")
("use a bold font" "Uzu aŭdacan tiparon")
("use a brown color" "uzu brunan koloron")
("use a calligraphic font" "uzu kaligrafian tiparon")
("use a green color" "uzu verdan koloron")
("use a grey color" "uzu grizan koloron")
("use a magenta color" "Uzu magentan koloron")
("use a orange color" "uzu oranĝkoloron")
("use a pink color" "Uzu rozan koloron")
("use a red color" "Uzu ruĝan koloron")
("use a sans serif font" "uzu tiparon sans serif")
("use a typewriter font" "uzu tajpilo-tiparon")
("use a white color" "Uzu blankan koloron")
("use a yellow color" "Uzu flavan koloron")
("use as master" "uzi kiel mastro")
("use blackboard bold font" "uzi nigrablankan tiparon")
("use bold font series" "uzu aŭdacajn tiparojn")
("use calligraphical font" "uzu kaligrafian tiparon")
("use extensible brackets" "Uzu etendeblajn krampojn")
("use footnote font size" "Uzu grandnombran tiparon")
("use fraktur font" "uzi fraktur tiparon")
("use huge font size" "uzu grandegan tiparon")
("use italic font shape" "uzu italan tiparon")
("use large font size" "Uzu grandan tiparon")
("use left hand column as border" "uzu maldekstran kolumnon kiel limon")
("use line wrapping for lines which are longer than 80 characters" "Uzu linioplatformojn por linioj pli longaj ol 80 signoj")
("use margin kerning (protrusion)" "uzi marĝenan kernon (protrudo)")
("use medium font series" "uzi mezan tiparon")
("use normal font size" "uzu normalan tiparon")
("use package" "uzi pakaĵon")
("use paragraph width" "uzu alinean larĝon")
("use protrusion" "uzi protrudon")
("use really huge font size" "uzu vere grandegan tiparon")
("use relative path" "uzi relativan vojon")
("use right font shape" "uzu ĝustan tiparon")
("use right hand column as border" "Uzu dekstran kolumnon kiel limon")
("use roman font family" "uzu romanan tiparon familion")
("use row above as border" "uzu vicon supre kiel limon")
("use row below as border" "uzu vicon sube kiel limo")
("use sans serif font family" "uzu sans serif tiparon")
("use script font size" "uzi skriptan grandecon")
("use slanted font shape" "uzu deklivan tiparon")
("use small capitals" "uzu malgrandajn majuskloj")
("use small font size" "Uzu malgrandan tiparon")
("use small-caps font shape" "uzu malgrand-ĉapajn tipformojn")
("use the blackboard bold font" "uzu la nigrablankan tiparon")
("use the fraktur font" "uzu la fraktur-tiparon")
("use tiny font font size" "uzu malgrandan tiparon tiparon")
("use typewriter font family" "Uzu tajpilan familian tiparon")
("use very large font size" "uzu tre grandan tiparon")
("user interface" "uzantinterfaco")
("user interface language" "uzantinterfaca lingvo")
("user manual" "uzantlibro")
("user preferences" "uzantaj preferoj")
("user provided icons" "Uzanto provizis ikonojn")
("users of Cyrillic languages" "uzantoj de cirilaj lingvoj")
("users of oriental languages" "uzantoj de orientaj lingvoj")
("utf-8 with inputenc LaTeX package" "utf-8 kun inputenc LaTeX-pakaĵo")
("utilities" "utilecoj")
("value" "valoro")
("vanish" "malaperas")
("variable" "variablo")
("variant" "varianto")
("vector" "vektoro")
("verbatim" "verbatim")
("verbose" "verbose")
("verse" "verso")
("version" "versio")
("versioning tool" "versio de ilo")
("vertical" "vertikala")
("vertical after" "vertikala post")
("vertical alignment" "vertikala vicigo")
("vertical before" "vertikala antaŭ")
("vertical cell alignment" "vertikala ĉela vicigo")
("vertical margins" "vertikalaj randoj")
("vertical part" "vertikala parto")
("vertical position" "vertikala pozicio")
("vertical space" "vertikala spaco")
("vertical space after" "vertikala spaco post")
("vertical space before" "vertikala spaco antaŭ")
("vertical space stretchability" "vertikala spaca kapablo")
("vertical table alignment" "vertikala tabula vicigo")
("vertically align cell to the base" "vertikale vicigas ĉelon al la bazo")
("vertically center the cell" "vertikale centri la ĉelon")
("very large" "tre granda")
("very small" "tre malgranda")
("vietnamese" "viki")
("view" "vidu")
("visible" "videbla")
("visible except here" "videbla krom ĉi tie")
("visible from here on" "videbla de ĉi tie antaŭen")
("visible only here" "videbla nur ĉi tie")
("visible until here" "videbla ĝis ĉi tie")
("visited loci" "vizititaj locioj")
("wallet" "monujo")
("warning" "averto")
("wave" "ondo")
("web" "retejo")
("weight" "pezo")
("welcome" "bonvenon")
("welcome to GNU TeXmacs" "bonvenon al GNU TeXmacs")
("what is new" "kio estas nova")
("when finished" "kiam finiĝis")
("when line wrapping" "kiam linioparto")
("while" "dum")
("white" "blanka")
("whitespace" "blanka spaco")
("wide" "larĝa")
("wide accent" "larĝa akcento")
("wide bar" "larĝa stango")
("wide block" "larĝa bloko")
("wide colored" "larĝa koloro")
("wide float" "larĝa flosilo")
("wide footnote" "larĝa piednoto")
("wide tabular" "larĝa tabelaro")
("widescreen" "larĝekrano")
("width" "larĝo")
("width is exactly the specified width" "larĝo estas ĝuste la specifita larĝo")
("width is maximum of specified width and box width" "larĝo estas maksimume de specifita larĝo kaj skatola larĝo")
("width is minimum of specified width and box width" "larĝo estas minimuma de specifita larĝo kaj skatola larĝo")
("width magnification" "larĝa larĝo")
("window" "fenestro")
("window height" "fenestra alteco")
("window width" "fenestra larĝo")
("windows key" "Vindoza ŝlosilo")
("with" "kun")
("wrap lines" "envolvaj linioj")
("write a macro" "skribu makroon")
("write a name" "skribu nomon")
("write bold mathematics" "skribu aŭdacan matematikon")
("write bold text" "skribu aŭdacan tekston")
("write italic text" "skribi kursivan tekston")
("write sample text" "skribi ekzempla teksto")
("write strong text" "skribu fortan tekston")
("write typewriter text" "skribi tajpilan tekston")
("write verbatim text" "verki verban tekston")
("writing TeXmacs bibliography styles" "verkado de TeXmacs-bibliografiaj stiloj")
("writing data converters" "skribaj konvertiloj")
("writing documentation" "skriba dokumentado")
("writing your own style files" "Verkado de viaj propraj stildosieroj")
("written with TeXmacs" "skribita kun TeXmacs")
("wrong empty passphrase" "malĝusta malplena pasfrazo")
("wrong passphrase" "malĝusta pasfrazo")
("year" "jaro")
("yellow" "flava")
("you are attempting to open an encrypted file while" "Vi provas malfermi ĉifritan dosieron dum")
("you can also obtain" "vi ankaŭ povas akiri")
("you might consider enabling the experimental" "vi eble konsideros ebligi la eksperimenton")
("you must add a bibliography file" "vi devas aldoni bibliografian dosieron")
("you should also make sure that GnuPG is installed" "Vi ankaŭ devas certigi, ke GnuPG estas instalita")
("your document is back in its original state" "via dokumento revenas en sia originala stato")
("your first interface" "via unua interfaco")
("your language" "via lingvo")
("your personal dictionary has been modified" "Via persona vortaro estis modifita")
("zoom" "zoom")
("zoom in" "zomi")
("zoom out" "elĉerpi")
